#!/bin/bash
Name: XFree86
Version: 4.1.0
Release: 49.RHEL

%define with_chatr_hack_for_ia64 0

# Backported all of these RPM macro defines from 4.2.99.2 to 4.1.0 for
# specfile cleanup.  <mharris> Nov 18, 2002
# These defines must precede any usage or weird things may happen.
%define _x11dir             /usr/X11R6
%define _x11bindir          %{_x11dir}/bin
# All non-executable, non-library "data" that typically gets placed into
# /usr/X11R6/lib needs to use the _x11datadir macro to ensure it gets
# installed and packaged correctly on all architectures including x86_64
%define _x11datadir         %{_x11dir}/lib
%define _x11includedir      %{_x11dir}/include
# x86_64 (AMD Hammer) architecture puts 64bit libs in lib64, so we install
# all XFree86 libraries into /usr/X11R6/lib64 with the following macro
%define _x11libdir          %{_x11dir}/%{_lib}
%define _x11mandir          %{_x11dir}/man
# Added lib to fonts
%define _x11fontdir         %{_x11datadir}/X11/fonts

# Takes advantage of SMP systems when building if enabled.  Disable when
# debugging builds with major new XFree86 versions until parallel building is
# known to work again.
%define ParallelBuild		1
%define VerboseBuild		1
# Builds X with debug symbol info.  This results in *FRECKIN* *HUGE* packages.
# Enable this if you want to debug the modular X server.  As of gdb 5.0, this
# requires patches to gdb to be completely useful.
# I MEAN HUGE, ie 2-3 times the size!  Don't complain - you've been warned!
%define DebuggableBuild		0

%define Glide3version		20010520
%define Glide3Libver		3.10.0
# Only valid and used, if WithExternalMesa is set below
%define MesaPackageDep		3:3.4.2-10

%ifarch %{ix86} alpha ia64
%define BuildTdfx		1
%define BuildGlide3		1
%else
%define BuildTdfx		0
%define BuildGlide3		0
%endif

%define BuildXterm3d		1

# Command macros
%define __mkfontdir umask 133;%{_x11bindir}/mkfontdir -e %{_x11fontdir}/encodings -e %{_x11fontdir}/encodings/large
# Disable rpm from stripping XFree86's modules, etc...
%define __spec_install_post /usr/lib/rpm/brp-compress

Summary: The basic fonts, programs and docs for an X workstation.
BuildRoot: %{_tmppath}/%{name}-%{version}-root
License: MIT
Group: User Interface/X
BuildRequires: freetype-devel >= 2.0.1, flex >= 2.5.4a, bison, zlib-devel
BuildRequires: ncurses-devel, pam-devel, kudzu-devel, pciutils-devel, libtool
# This stuff is for Glide3
BuildRequires: autoconf, automake, libtool
Requires: XFree86-xfs = %{version}, XFree86-libs = %{version}
Requires: /etc/pam.d/system-auth
# kernel-drm requirement is so DRI works properly.  The kernel RPM package
# should have a "Provides: kernel-drm = 4.1.0".  Future kernels that provide
# new kernel-drm, should list all supported DRM interfaces with multiple
# Provides: lines.  <mharris@redhat.com>
%ifarch %{ix86} alpha ia64
Requires: kernel-drm = 4.1.0
%endif
Prereq: /bin/ln, /usr/sbin/chkfontpath, %{_x11bindir}/mkfontdir
BuildRequires: Mesa-devel >= %{MesaPackageDep}
Requires: Mesa >= %{MesaPackageDep}

%if %{BuildXterm3d}
BuildRequires: Xaw3d-devel
%endif

Obsoletes: XFree86-ATI XFree86-Alliance XFree86-ChipsTechnologies
Obsoletes: XFree86-Cirrus XFree86-Cyrix XFree86-i740 XFree86-i810
Obsoletes: XFree86-mga XFree86-NeoMagic XFree86-NVidia XFree86-Rage128
Obsoletes: XFree86-Rendition XFree86-SiS XFree86-3dfx XFree86-Trident
Obsoletes: XFree86-Tseng XFree86-V4L tdfx_dri X11R6-contrib
Obsoletes: XFree86-ISO8859-2-Type1-fonts
# Some files moved from XFree86-doc to XFree86 main package in 4.1.0, causing
# a file conflict error to occur on upgrade unless the doc subpackage is also
# upgraded.
Conflicts: XFree86-doc < 4.1.0-3

# Source files
Source:   XFree86-%{version}-bindist.tar.bz2
Source3:  xserver.pamd
Source4:  xdm.pamd
Source5:  xfs.init
Source6:  xfs.config
Source7:  xdm.init
Source8:  eurofonts-X11.tar.bz2
Source11: XFree86-ISO8859-2-Fontmap
# GLIDE 3 - Create the Glide3 tarball by using:
#  cvs -d :pserver:anonymous@cvs.glide.sourceforge.net:/cvsroot/glide co Glide3
#  pushd Glide3 ; find . -name CVS -type d |xargs rm -rf
#  find . -name .cvsignore | xargs rm ; popd
#  tar Icf Glide3-$(date +"%Y%m%d").tar.bz2 Glide3/
Source12: Glide3-%{Glide3version}.tar.bz2
# FIXME: glidelink *should* be no longer necessary as of XFree86 4.2.0
Source13: glidelink.c
# Savage driver 1.1.27t dropin (Apr 19, 2003) <mharris@redhat.com>
# This is Tim Roberts' latest Savage driver
Source14: http://www.probo.com/timr/savage-1.1.27t.tgz
Source20: XftConfig.redhat
# WARNING:  The following program 'chatr' is used after the X server is
#           built to modify the generated binary to work correctly.  It is
#           an ugly hack, which should be temporary until a better fix is
#           available.  <notting>
Source25: chatr.c 

# Patches  0-9 are for things that *must* be patched first
# This patch must be applied first as it brings stock source tarball up to 
# date with the latest stable XFree86 branch source. (not trunk)
Patch0:   XFree86-4.1.0-xf-4_1-branch-2001-11-28.patch
Patch2:   XFree86-ISO8859-2-1.0-redhat.patch
Patch7:   XFree86-4.0-xtermresources.patch
# Added from user RFE 48783 (Jul 24, 2001)
Patch8:   XFree86-4.1.0-xtermresources-2.patch
Patch12:  XFree86-4.0-broken-includes.patch
# Patches 10-19 are for Glide3
Patch10:  glide-ia64.patch
# Get rid of many compiler warnings
Patch11:  Glide3-redhat-cleanup-1.patch
# Patches 100-119: ati driver patches
Patch100: XFree86-4.1.0-ati-mach64-rage-XL.patch


Patch114: XFree86-4.1.0-ati-xf86PciInfo.h-update-r128.patch
Patch118: XFree86-4.1.0-ati-atichip-atiprobe-update.patch
# PATCHES 120-129 for ATI Rage 128
# Adds support for all Rage 128 hardware that was previously unsupported in 4.1.0
# (barring bugs and accidental ommissions of course) Mike A. Harris <mharris@redhat.com>
Patch120: XFree86-4.1.0-ati-r128-all-chip-support.patch

# Patches 140-159: radeon driver patches
# Updated 4.1.0 drivers from ATI (Radeon VE, and various r128 additions, etc)
Patch140: XFree86-4.1.0-ati-radeon-ve-update.patch
# Prevent lockups on fast machines when VT switching
Patch141: XFree86-4.1.0-radeon-slowdownthere.patch
#Patch142: XFree86-4.1.0-ati-pciids-cleanup.patch
Patch143: XFree86-4.1.0-ati-radeon-dri-buildfix.patch
# Fixes hardware cursor on left side of screen Mike A. Harris <mharris@redhat.com>
Patch145: XFree86-4.1.0-radeon-hardware-cursor-fix.patch
Patch146: XFree86-4.1.0-ati-radeon-unresolved-drm-symbols.patch
Patch147: XFree86-4.1.0-ati-radeon-xvideo-name.patch
Patch149: XFree86-4.1.0-ati-radeon-mobility-m6-fix1.patch
Patch150: XFree86-4.1.0-ati-radeon-mobility-m6.patch
Patch151: XFree86-4.1.0-ati-radeon-mobility-m6-fpfixes.patch
# Radeon CP 2D accel patch to improve performance, plus a few bugfixes
Patch152: XFree86-4.1.0-ati-radeon-cp-accel.patch
Patch153: XFree86-4.1.0-ati-radeon-pagesize-fixes.patch

# Patches 160-169: mga driver patches
# Patches 170-179: savage driver patches
# Patches 180-189: tdfx card driver patches

# Patches 190-199: cirrus driver patches
Patch190: XFree86-4.1.0-cirrus-foobaroo-fix.patch

# Patches 200-209: neomagic driver patches
Patch200: XFree86-4.1.0-neomagic-dga.patch

# Fix from Adam Richter for s3 Virge MX
Patch210: XFree86-4.1.0-s3virge-mx.patch

Patch305: XFree86-4.0.2-xfree86.lst.patch
# Adds 1400x1050 video modelines to XFree for some laptops, etc.
# FIXME: Is this still required?  I believe it is in 4.0.99.x already...
Patch315: XFree86-4.0.2-defmodes-1400.patch
# Neomagic 256XL+ (NM2380) in sony laptops need this to work properly
Patch323: XFree86-4.0.2-neomagic_swcursor.patch
# Fix for r128 DRI from Gareth Hughes at VA Linux
Patch335: XFree86-4.0.2-r128-drm-do-wait-for-fifo.patch
# Fix bad page size assumptions in DRI drivers <mharris@redhat.com>
Patch405: XFree86-4.1.0-pagesize-fixup.patch
# Fixes (#31618) freed memory being deref'd in xaw <jik@kamens.brookline.ma.us>
Patch406: XFree86-4.0.3-xaw-freed-mem-deref.patch
# Fixes (#33152) - <jik@kamens.brookline.ma.us>
Patch407: XFree86-4.0.3-xaw-readtext.patch
# Fixes (#31540) - <jik@kamens.brookline.ma.us> emacs style flashing paren fix
Patch408: XFree86-4.0.3-xaw-flashing-paren.patch
# Xaw fixup <jik@kamens.brookline.ma.us>
Patch420: XFree86-4.0.3-xaw-asciisink.patch
# Fixes DPMS on dualhead g400/g450 (#35180)
Patch419: XFree86-4.0.3-mga-dualhead-dpms.patch
# CUSTOM startup messages (Currently does nothing) Mike A. Harris <mharris@redhat.com>
Patch421: XFree86-4.0.3-rhl-startupmessages.patch
# Manpage fixup  Mike A. Harris <mharris@redhat.com>
Patch422: XFree86-4.0.3-xset-man-update.patch

# Patch series 500 started at (4.0.3-3 specfile fork to 4.0.99.1).  Last
# 4.0.3 patch at the time was 404 XFree86-4.0.3-xdm-pam.patch

# New parallel make patch courtesy of  H.J. Lu <hjl@gnu.org>
Patch500: XFree86-4.0.99.900-parallelmake.patch
# Patch to speed up compilation by not doing "make clean" at the beginning of building"
Patch501: XFree86-4.1.0-makefile-fastbuild.patch
# Makes ALT keys default to being Meta instead of Winkeys on 104+ keyboads
Patch502: XFree86-4.0.99.1-winkey-alt-meta.patch
# Matrox G450 driver  Luugi Marsan <lmarsan@matrox.com>, David Woodhouse <dwmw2@redhat.com>
Patch503: XFree86-4.0.99.1-mga-g450-dualhead.patch
Patch504: XFree86-4.0.99.3-Xwrapper.patch
Patch505: XFree86-4.0.99.3-xman.patch
# Patch so that X can find the included Glide3 libraries for tdfx driver
Patch507: XFree86-4.0.99.3-glide3-libdir.patch

Patch1000: XFree86-4.0.1-drm.patch
Patch1001: XFree86-4.1-xinerama.patch
Patch1003: XFree86-4.0.99.901-redhat-xdm-pam.patch

# DRM fixes from Alan's 2.4.5ac5 kernel patch Mike A. Harris <mharris@redhat.com>
Patch1005: XFree86-4.0.99.901-drm-fix-from-2.4.5ac5.patch
# Adds missing symbol's to Glint driver Mike A. Harris <mharris@redhat.com>
Patch1006: XFree86-4.1.0-redhat-glint-missing-symbols.patch
# Xaw3d patch to xterm  H.J. Lu <hjl@gnu.org>
Patch1007: XFree86-4.0.2-xterm-Xaw3d.patch
# TEMPORARILY MOVED HERE for patch reorganization
Patch1009: XFree86-4.0.1-alpha-pcibus-lemming.patch
Patch1010: XFree86-4.0.1-pic.patch
# New modeline - (#44112)
Patch1011: XFree86-4.1.0-modeline-1152x864x85Hz.patch
Patch1013: XFree86-4.1.0-allow-module-flags.patch
# Megapatch from Compaq for alpha
Patch1015: XFree86-4.1.0-compaq-alpha-megapatch.patch
# Fixes bug #49674
Patch1017: XFree86-4.1.0-twm-coredumpfix.patch
# -frame option is ignored if -id option used <mharris@redhat.com>
Patch1018: XFree86-4.1.0-xwd-frame-option.patch
# Fixes DoS bug in xfs   Paulo de Andrade <pcpa@conectiva.com.br>
Patch1020: XFree86-4.1.0-xfs-DoS.patch
# load agpgart for DRM
Patch1021: XFree86-4.1.0-agpgart-load.patch
# Add support for nn_NO locale aliases
Patch1022: XFree86-4.1.0-locale.alias-nn_NO.patch
# Add support for Japanese 109 key USB keyboard
Patch1023: XFree86-4.1.0-keyboard-jp109usb.patch
# Force mkfontdir to make fonts.dir and encodings.dir, etc. mode 0644 Mike A. Harris <mharris@redhat.com>
Patch1024: XFree86-4.1.0-mkfontdir-perms.patch
# Adds en_GB aliases and en_US (#47247)
Patch1027: XFree86-4.1.0-locale-alias-en_GB.patch
# Fixes xman bug by using s/zsoelim/soelim/.  Also, a symlink added to groff package. mharris@redhat.com
Patch1028: XFree86-4.1.0-xman-soelim-fix.patch
# Fixes unaligned trap error on Alpha
Patch1029: XFree86-4.1.0-glFrustum-fixie.patch
# Don't build or include PEX documentation (it is deprecated and obsolete)
Patch1030: XFree86-4.1.0-dont-build-pex-docs.patch
# Fix for Xinerama/Xv extmod bug in bug #52842
Patch1031: XFree86-4.1.0-xinerama-extmod-fix.patch
# Fix for abnt2 keycodes (#55128)
Patch1033: XFree86-4.1.0-keycodes-abnt2.patch

# S390 patches (will be moved to arch specific section later)
Patch3000: XFree86-4.1.0-s390x.patch
Patch3001: XFree86-4.0.1-nohardware.patch
Patch3002: XFree86-4.0.2-FreeType-s390x.patch
Patch3004: xdm-4.0-servonly.patch
Patch3005: XFree86-4.1.0-cpp-s390x.patch
# Fixes bug #20659 Trident VTswitch bug
Patch3006: XFree86-4.1.0-TridentCyber9525.patch
# Patches for PPC
Patch3007: XFree86-4.1.0-ppc-compiler-workaround.patch
# Patches for Sparc
Patch3500: XFree86-4.1.0-sunffb-4.1.99-DPMSMode.patch
Patch3501: XFree86-4.1.0-xkbcomp-alias.patch

# Chinese i18n support patches
Patch4004: XFree86-4.1.0-gb18030.patch
Patch4005: XFree86-4.1.0-xtt.patch
Patch4006: XFree86-4.1.0-gb2312-gbk.enc.patch
# This patch is wrong.  Nobody's filed bug reports or complained though, so
# I'm leaving it here so as not to risk causing breakage of something by
# removing it, even though it is acknowledged as totally wrong.
Patch4007: XFree86-4.1.0-utf8.patch
Patch4008: XFree86-4.1.0-locale-alias-gb18030.patch
# Alpha patches from Compaq
Patch5000: XFree86-4.1.0-compaq-alpha-drm.patch
Patch5001: XFree86-4.1.0-compaq-alpha-drm-install.patch
Patch5002: XFree86-4.1.0-compaq-alpha-enable-pci-validate.patch
Patch5003: XFree86-4.1.0-compaq-alpha-kbdrepeat.patch
Patch5004: XFree86-4.1.0-compaq-alpha-noint21func4e.patch
Patch5005: XFree86-4.1.0-compaq-alpha-pci_validate.patch
Patch5006: XFree86-4.1.0-compaq-alpha-radeon-dri-fbmap.patch
Patch5007: XFree86-4.1.0-compaq-alpha-radeon-int10-save.patch
Patch5008: XFree86-4.1.0-compaq-alpha-rv200.patch
Patch5009: XFree86-4.1.0-compaq-alpha-truncate-bios.patch
Patch5010: XFree86-4.1.0-compaq-alpha-101_anyhose-XFree86-rh410-8-200202041558.patch
Patch5011: XFree86-4.1.0-compaq-alpha-100_vga_en_on_invisible_host_bridge-XFree86-rh410-8-200201250722.patch
# MIT SHM security patch
Patch5100: XFree86-4.1.0-mitshm.patch
Patch5101: XFree86-4.1.0-mitshm2.patch
# Fixes time wraparound bug in X server - Chris Blizzard <blizzard@redhat.com>
Patch5102: XFree86-4.1.0-time-wraparound.patch
# New fixes from April 18, 2002 and later
Patch6000: XFree86-4.2.0-drm-device-dir-perms.patch
Patch6001: XFree86-4.1.0-misc-fixes-from-debian.patch

# 8000 series - ia64 patches
# This is disabled below, and should be removed.  It is just wrong.
Patch8000: XFree86-4.1.0-int10-hplso.patch
Patch8001: XFree86-4.1.0-pci-hplso.patch
Patch8002: XFree86-4.1.0-primpci-hplso.patch
Patch8003: XFree86-4.1.0-ps2-hplso.patch
# This memory barrier patch hacks around a *kernel* bug, which needs to
# be fixed properly in the kernel.
Patch8004: XFree86-4.1.0-ia64-vgaHW-memory-barrier2.patch
# This patch disables solid 2 point lines on PCI Radeon to work around bug
# #71701 Newer version of above, disables SolidTwoPointLine on ia64
Patch8006: XFree86-4.2.0-ati-radeon-ia64-no-solid-two-point-line-2.patch
# This memory barrier patch hacks around a *kernel* bug, which needs to
# be fixed properly in the kernel.
Patch8007: XFree86-4.1.0-ia64-nv-memory-barrier.patch
Patch8008: XFree86-4.1.0-ia64-nv-riva-ia64-stability.patch
# Add minimal unsupported 2D operation for Quadro 4 900/750/700 for HP
Patch8009: XFree86-4.1.0-ia64-nv-quadro-900-750-700-unsupported.patch
# Add minimal unsupported 2D operation for Quadro 4 980/380 for HP
Patch8010: XFree86-4.1.0-ia64-nv-quadro-980-380-unsupported.patch
# Patch to work around int10 issue on HP ia64 boxes <jdennis@redhat.com>
Patch8011: XFree86-4.1.0-ati-skip-int10-on-hp-ia64.patch
Patch8012: XFree86-4.1.0-ia64-disable-int10-on-hp-zx1.patch
Patch8013: XFree86-4.1.0-elf-loader-mmap-prot-exec.patch

# This patches XFree's Imake files to autodetect the compiler being used,
# and disable merge-constants on modules if it is needed. (currently unapplied)
Patch8100: XFree86-4.1.0-disable-merge-constants-on-modules.patch
# Backport of fix from CVS head to make GetTimeInMillis() monotonic
Patch8101: XFree86-4.1.0-timestamp-monotonicity.patch
Patch8102: XFree86-4.1.0-xdm-devmem.patch
Patch8103: XFree86-4.2.99.901-xauth-diskfull.patch

Patch8104: XFree86-4.1.0-xterm-DECUDK-security-fix.patch
Patch8105: XFree86-4.2.1-xterm-can-2003-0063.patch
Patch8106: XFree86-4.1.0-xdm-auth_dir.patch
Patch8107: XFree86-4.1.0-redhat-bug-report-address-update.patch

Patch10000: XFree86-4.1.0-redhat-lock-version.patch
Patch10001: XFree86-4.1.0-redhat-version-change-detection.patch

%package xfs
Summary: A font server for the X Window System.
Group: System Environment/Daemons
Prereq: fileutils sed
Prereq: shadow-utils
Requires: XFree86-libs = %{version}

%package twm
Summary: A simple window manager
Group: User Interface/X
Requires: XFree86, XFree86-libs = %{version}
Provides: windowmanager

%package devel
Obsoletes: xpm-devel
Provides: xpm-devel
Summary: X11R6 static libraries, headers and programming man pages.
Group: Development/Libraries
Requires: XFree86-libs = %{version}

%package xdm
Summary: X Display Manager
Requires: XFree86 = %{version}, /etc/pam.d/system-auth
# xinitrc requirement on 3.13 for user login shell enhancement to Xsession
Requires: xinitrc >= 3.13
Group: User Interface/X

%package libs
Summary: Shared libraries needed by the X Window System version 11 release 6.4
Group: System Environment/Libraries
Obsoletes: xpm
Prereq: /sbin/ldconfig grep textutils
Obsoletes: Glide3
Provides:  Glide3
# The files (XErrorDB, XKeysymDB, rgb.txt) moved from XFree86 to XFree86-libs
# subpackage in 4.1.0-43 for AS 2.1 enhancement request - bugzilla bug (#79488)
Conflicts: XFree86 < 4.1.0-43

%package 75dpi-fonts
Summary: A set of 75dpi resolution fonts for the X Window System.
Group: User Interface/X
Prereq: /usr/sbin/chkfontpath, %{_x11bindir}/mkfontdir

%package 100dpi-fonts
Summary: A set of 100dpi resolution fonts for the X Window System.
Group: User Interface/X
Prereq: /usr/sbin/chkfontpath, %{_x11bindir}/mkfontdir

%package ISO8859-2-75dpi-fonts
Summary: A set of 75dpi Central European language fonts for X.
Group: User Interface/X
Prereq: /usr/sbin/chkfontpath, %{_x11bindir}/mkfontdir

%package ISO8859-2-100dpi-fonts
Summary: A set of 100dpi Central European language fonts for X.
Group: User Interface/X
Prereq: /usr/sbin/chkfontpath, %{_x11bindir}/mkfontdir

%package ISO8859-9-75dpi-fonts
Summary: ISO8859-9-75dpi-fonts
Group: User Interface/X
Prereq: /usr/sbin/chkfontpath, %{_x11bindir}/mkfontdir

%package ISO8859-9-100dpi-fonts
Summary: ISO8859-9-100dpi-fonts
Group: User Interface/X
Prereq: /usr/sbin/chkfontpath, %{_x11bindir}/mkfontdir

%package ISO8859-15-75dpi-fonts
Summary: ISO8859-15-75dpi-fonts
Group: User Interface/X
Prereq: /usr/sbin/chkfontpath, %{_x11bindir}/mkfontdir

%package ISO8859-15-100dpi-fonts
Summary: ISO8859-15-100dpi-fonts
Group: User Interface/X
Prereq: /usr/sbin/chkfontpath, %{_x11bindir}/mkfontdir

%package ISO8859-2-Type1-fonts
Summary: A set of Type1 Central European language fonts for X.
Group: User Interface/X
Prereq: /usr/sbin/chkfontpath, %{_x11bindir}/mkfontdir

%package cyrillic-fonts
Summary: Cyrillic fonts for X.
Group: User Interface/X
Prereq: /usr/sbin/chkfontpath, %{_x11bindir}/mkfontdir

%ifnarch s390 s390x
%package doc
Summary: Documentation on various X11 programming interfaces.
Group: Documentation
%endif

%package Xnest
Summary: A nested XFree86 server.
Group: User Interface/X Hardware Support
Requires: XFree86 = %{version}

%package Xvfb
Summary: A virtual framebuffer X Windows System server for XFree86.
Group: User Interface/X Hardware Support
Requires: XFree86 = %{version}

%package tools
Summary: Various tools for XFree86
Group: User Interface/X
Obsoletes: X11R6-contrib
Requires: XFree86

%ifnarch ia64 s390 s390x
%package xf86cfg
Summary: XFree86 configuration program
Group: User Interface/X
Obsoletes: XFree86-XF86Setup
Requires: XFree86 = %{version}
Requires: Xconfigurator
%endif



########## DESCRIPTIONS ##############################################

%description
The X Window System provides the base technology for developing
graphical user interfaces. Simply stated, X draws the elements
of the GUI on the user's screen and builds methods for sending
user interactions back to the application. X also supports remote
application deployment--running an application on another computer
while viewing the input/output on your machine.  X is a powerful
environment which supports many different applications, such as
games, programming tools, graphics programs, text editors, etc.
XFree86 is the version of X which runs on Linux, as well as on other
platforms.

This package contains the basic fonts, programs and documentation
for an X workstation.  However, this package doesn't provide the
program which you will need to drive your video hardware.  To
control your video card, you'll need the particular X server
package which corresponds to your computer's video card.

Additionally, you will need to install the Xconfigurator package, the xfs
X font server package and the XFree86-libs package.
You may also need to install one or more of the XFree86 fonts packages.

And finally, if you are going to develop applications that run as
X clients, you will also need to install XFree86-devel.


%description libs
XFree86-libs contains the shared libraries that most X programs
need to run properly. These shared libraries are in a separate package
in order to reduce the disk space needed to run X applications on a
machine without an X server (i.e., over a network).

If you are installing the X Window System on your machine, you will
need to install XFree86-libs.  You will also need to install the
following packages: XFree86, one or more of the XFree86 fonts
packages, Xconfigurator, XFree86-xfs.  If you are
going to develop applications that run as X clients, you will also
need to install XFree86-devel.


%description Xvfb
Xvfb (X Virtual Frame Buffer) is an X server that is able to run on
machines with no display hardware and no physical input devices.
Xvfb emulates a dumb framebuffer using virtual memory.  Xvfb doesn't
open any devices, but behaves otherwise as an X display.  Xvfb is
normally used for testing servers.  Using Xvfb, the mfb or cfb code
for any depth can be exercised without using real hardware that
supports the desired depths.  Xvfb has also been used to test X clients
against unusual depths and screen configurations, to do batch
processing with Xvfb as a background rendering engine, to do load
testing, to help with porting an X server to a new platform, and to
provide an unobtrusive way of running applications which really don't
need an X server but insist on having one.

If you need to test your X server or your X clients, you may want to
install Xvfb for that purpose.

%description Xnest
Xnest is an X Window System server which runs in an X window.
Xnest is actually a client of the real X server, which manages
windows and graphics requests for Xnest, while Xnest manages the
windows and graphics requests for its own clients.

You will need to install Xnest if you require an X server which
will run as a client of your real X server (perhaps for testing
purposes).

%description ISO8859-2-75dpi-fonts
The XFree86-ISO8859-2-75dpi-fonts package contains a set of Central
European language fonts in 75 dpi resolution for the X Window System.
If you have a high resolution monitor capable of supporting 100 dpi,
you should install the 100 dpi version of this package instead.

%description ISO8859-2-100dpi-fonts
The XFree86-ISO8859-2-100dpi-fonts package includes Central European
(ISO8859-2) fonts, in 100 dpi resolution, for the X Window System.

%description ISO8859-9-75dpi-fonts
The XFree86-ISO8859-9-75dpi-fonts package contains Turkish language
(ISO8859-9) fonts, in 75 dpi resolution, for the X Window System.

%description ISO8859-9-100dpi-fonts
The XFree86-ISO8859-9-100dpi-fonts package contains Turkish language
(ISO8859-9) fonts, in 100 dpi resolution, for the X Window System.

%description ISO8859-15-75dpi-fonts
The XFree86-ISO8859-15-75dpi-fonts package contains a set of Latin1
fonts with Euro character, in 75 dpi resolution, for the X Window System.

%description ISO8859-15-100dpi-fonts
The XFree86-ISO8859-15-100dpi-fonts package contains a set of Latin1
fonts with Euro character, in 100 dpi resolution, for the X Window System.

%description ISO8859-2-Type1-fonts
The XFree86-ISO8859-2-Type1-fonts package contains Central European
Type 1 fonts for the X Window System.

%description 75dpi-fonts
XFree86-75dpi-fonts contains the 75 dpi fonts used on most X Window
Systems. If you're going to use the X Window System, you should
install this package, unless you have a monitor which can support 100
dpi resolution.  In that case, you may prefer the 100dpi fonts
available in the XFree86-100dpi-fonts package.

%description 100dpi-fonts
The XFree86-100dpi-fonts package contains a set of 100 dpi fonts used
on most Linux systems. If you're going to use the X Window System and
you have a high resolution monitor capable of 100 dpi, you should
install XFree86-100dpi-fonts.

%description cyrillic-fonts
The XFree86-cyrillic-fonts package includes the Cyrillic fonts
included with XFree86 3.3.2 and higher. If you use a language that
requires the Cyrillic character set, you should install
XFree86-cyrillic-fonts.

%ifnarch s390 s390x
%description doc
XFree86-doc provides a great deal of documentation, in PostScript
format, on the various X APIs, libraries, and other interfaces.  If
you need low level X documentation, you will find it here.  Topics
include the X protocol, the ICCCM window manager standard, ICE
session management, the font server API, etc.
%endif

%description xdm
X Display Manager.

%description xfs
XFree86-xfs contains the font server for XFree86.  Xfs can also serve
fonts to remote X servers. The remote system will be able to use all
fonts installed on the font server, even if they are not installed on
the remote computer.

You'll need to install XFree86-xfs if you're installing the X Window
System. You'll also need to install the following packages: XFree86,
the XFree86 X server for your video card, the XFree86 fonts package(s)
appropriate for your system, Xconfigurator and XFree86-libs.

%description devel
XFree86-devel includes the libraries, header files and documentation
you'll need to develop programs which run as X clients. XFree86-devel
includes the base Xlib library as well as the Xt and Xaw widget sets.

Install XFree86-devel if you are going to develop programs which
will run as X clients.

%description twm
A simple and lightweight window manager

%description tools
Various tools for X, including listres, xbiff, xedit, xeyes, xcalc, xload
and xman, among others.

If you're using X, you should install XFree86-tools.  You will also
need to install the XFree86 package, the XFree86 package which
corresponds to your video card, one of the XFree86 fonts packages, the
Xconfigurator package and the XFree86-libs package.

Finally, if you're going to develop applications that run as X clients,
you will also need to install XFree86-devel.

This package contains all applications that used to be in X11R6-contrib
in older releases.

%ifnarch ia64 s390 s390x
%description xf86cfg
Configuration tool for XFree86
%endif

##########  PREP  ###################################################
%prep
%setup -q -c -a 12
##########  PATCH  ##################################################
%patch0 -p0 -b .xf-4_1-branch

%patch2 -p1 -b .patch-redhat
%patch7 -p1 -b .xtermresources
%patch8 -p0 -b .xtermresources-2
%patch12 -p1 -b .patch-broken

%if %{BuildGlide3}
%patch10 -p0 -b .glide-ia64
%patch11 -p0 -b .Glide3-redhat-cleanup-1
%endif

%patch114 -p0 -b .ati-xf86PciInfo.h-update-r128
%patch118 -p0 -b .ati-atichip-atiprobe-update
%patch120 -p0 -b .ati-r128-all-chip-support

# Added Wed, July 25, 2001, <mharris@redhat,com>
%patch140 -p0 -b .ati-radeon-ve-update
%patch141 -p0 -b .ati-radeon-slowdownthere

# Must apply after Radeon patches.

#%patch142 -p0 -b .ati-pciids-cleanup
%patch143 -p0 -b .ati-radeon-dri-buildfix
%patch145 -p0 -b .radeon-hardware-cursor-fix
%patch146 -p0 -b .ati-radeon-unresolved-drm-symbols
%patch147 -p0 -b .ati-radeon-xvideo-name
# Applied here as prior patches need to be applied first.
%patch100 -p0 -b .ati-mach64-rage-XL

%patch152 -p0 -b .radeon-cp-accel
%patch153 -p0 -b .ati-radeon-pagesize-fixes

%patch190 -p0 -b .cirrus-foobaroo-fix
%patch200 -p0 -b .neomagic-dga

%patch210 -p0 -b .s3virge-mx

%patch305 -p0 -b .patch-xfree86.lst

%patch315 -p0 -b .defmodes-1400
%patch323 -p1 -b .neomagic_swcursor

%patch405 -p0 -b .pagesize-fixup
%patch406 -p0 -b .xaw-freed-mem-deref
%patch407 -p0 -b .xaw-readtext
%patch408 -p0 -b .xaw-flashing-paren

# Disabled: not considered a crucial fix - might mess up working code
# also it is untested - enable at own risk.  No bad reports received..
#%patch419 -p1 -b .mga-dualhead-dpms

%patch420 -p1 -b .xaw-asciisink

# CUSTOM startup messages patch.  XFree86 added to the trunk what this
# patch was currently doing more or less, however it will be updated
# later so I'm leaving it here.
#%patch421 -p0 -b .rhl-startupmessages

%patch422 -p0 -b .xset-man-update

# The parallel make patch might patch stuff that is fixed in a different
# way now, but that doesn't conflict with the patch.  Disabled to be safe.
%if %{ParallelBuild}
%patch500 -p0 -b .parallelmake
%patch501 -p0 -b .makefile-fastbuild
%endif

%patch502 -p1 -b .winkey-alt-meta
%patch504 -p1 -b .patch-Xwrapper
%patch505 -p0 -b .patch-xman

# Remove this patch if glide3 gets separated back out
%if %{BuildGlide3}
%patch507 -p0 -b .glide3-libdir
%endif

# Drop in Savage driver update:
{
   echo "Applying SAVAGE driver tarball"
   pushd xc/programs/Xserver/hw/xfree86/drivers/savage
   tar zxvf %{SOURCE14}
   popd
}

# MISC new patches go here until I finish the patch reorganization, this
# stuff is likely to move around a lot over the next while (Jun 8, 2001)
%patch1000 -p1 -b .patch-drm
%patch1001 -p1 -b .xinerama
%patch1003 -p0 -b .redhat-xdm-pam

# Doesn't apply to 4.0.99.x  - for 4.0.3 only?
#%patch1005 -p0 -b .drm-fix-from-2.4.5ac5

#%patch1006 -p0 -b .redhat-glint-missing-symbols

# HJL's Xterm3d patch
%if %{BuildXterm3d}
%patch1007 -p1 -b .patch-Xaw3d
%endif
%ifarch alpha
%patch1009 -p0 -b .lemming
%endif

%ifarch ia64
%patch1010 -p1 -b .patch-pic
%endif
%patch1011 -p0 -b .modeline-1152x864x85Hz
%patch1013 -p0 -b .allow-module-flags

%ifarch alpha
%patch1015 -p0 -b .compaq-alpha-megapatch
%endif

%patch1017 -p0 -b .twm-coredumpfix
%patch1018 -p0 -b .xwd-frame-option
# Disabled, included in latest stable update 2001/08/09
# Reverse applied to back out DoS fix as it blows up serving to 3.3.6 servers
#%patch1020 -R -p0 -b .xfs-DoS-fix
%patch1021 -p1 -b .agpgart-load
%patch1022 -p0 -b .locale.alias-nn_NO
%patch1027 -p0 -b .locale-alias-en_GB

# Add support for Japanese 109 key USB keyboard
%patch1023 -p0 -b .keyboard-jp109usb
%patch1024 -p0 -b .mkfontdir-perms
%patch1028 -p0 -b .xman-soelim-fix

%ifarch alpha
%patch1029 -p0 -b .glFrustum-fixie
%endif

%patch1030 -p0 -b .dont-build-pex-docs
%patch1031 -p0 -b .xinerama-extmod-fix
%patch1033 -p0 -b .keycodes-abnt2

%ifarch s390 s390x
%patch3000 -p1 -b .patch-s390
%patch3001 -p1 -b .s390-nohardware
%patch3002 -p1 -b .s390-freetype
%patch3005 -p1 -b .s390-cpp
%endif

%patch3004 -p1 -b .xdm-servonly
%patch3006 -p0 -b .TridentCyber9525

# PPC patches
%ifarch ppc ppc64
%patch3007 -p1 -b .ppc-compiler-workaround
%endif

%ifarch sparc sparc64
%patch3500 -p0 -b .sunffb-4.1.99-DPMSMode
%patch3501 -p0 -b .xkbcomp-alias
%endif

# Chinese i18n support patches
%patch4004 -p0 -b .gb18030-support
%patch4005 -p0 -b .gb18030-xtt-support
%patch4006 -p0 -b .gb2312-gbk-enc-support
%patch4007 -p0 -b .utf8-bugfix
%patch4008 -p0 -b .locale-alias-gb18030

# Alpha patches from Compaq
%ifarch alpha
%patch5000 -p0 -b .compaq-alpha-drm
%patch5001 -p0 -b .compaq-alpha-drm_install
%patch5002 -p0 -b .compaq-alpha-enable-pci-validate
%patch5003 -p0 -b .compaq-alpha-kbdrepeat
%patch5004 -p0 -b .compaq-alpha-noint21func4e
%patch5005 -p0 -b .compaq-alpha-pci_validate
%patch5006 -p0 -b .compaq-alpha-radeon-dri-fbmap
%patch5007 -p0 -b .compaq-alpha-radeon-int10-save
%patch5008 -p0 -b .compaq-alpha-rv200
%patch5009 -p0 -b .compaq-alpha-truncate-bios
%patch5010 -p0 -b .compaq-alpha-anyhose
%patch5011 -p0 -b .compaq-alpha-100_vga_en_on_invisible_host_bridge-XFree86-rh410-8-200201250722
%endif

%patch5100 -p0 -b .mitshm
%patch5101 -p0 -b .mitshm2
%patch5102 -p0 -b .time-wraparound

%patch6000 -p0 -b .drm-device-dir-perms
%patch6001 -p0 -b .misc-fixes-from-debian

%ifarch ia64
# This patch is just WRONG, and is disabled as of 4.1.0-39 <mharris>
#%patch8000 -p0 -b .int10-hplso
%patch8001 -p0 -b .pci-hplso
%patch8002 -p0 -b .primpci-hplso
%patch8003 -p0 -b .ps2-hplso
%patch8004 -p0 -b .ia64-vgaHW-memory-barrier
%patch8006 -p0 -b .ati-radeon-ia64-no-solid-two-point-line-2
%patch8007 -p0 -b .nv-ia64-memory-barrier
%patch8008 -p0 -b .nv-riva-ia64-stability
%patch8009 -p0 -b .ia64-nv-quadro-900-750-500-unsupported
%patch8010 -p0 -b .ia64-nv-quadro-980-380-unsupported
#%patch8011 -p0 -b .ia64-ati-skip-int10-on-hp-zx1
%patch8012 -p0 -b .ia64-disable-int10-on-hp-zx1
%endif

%if ! %{with_chatr_hack_for_ia64}
%patch8013 -p0 -b .elf-loader-mmap-prot-exec
%endif

%patch8100 -p0 -b .disable-merge-constants-on-modules
%patch8101 -p0 -b .timestamp-monotonicity
%patch8102 -p0 -b .xdm-devmem
%patch8103 -p0 -b .xauth-diskfull

%patch8104 -p0 -b .xterm-DECUDK-security-fix
%patch8105 -p0 -b .xterm-can-2003-0063
%patch8106 -p0 -b .xdm-auth_dir
%patch8107 -p0 -b .redhat-bug-report-address-update

# These are special patches to detect version skew and lock the server at 4.1.0
#%patch10000 -p0 -b .redhat-lock-version
%patch10001 -p0 -b .redhat-version-change-detection

######################################################################
#####  CREATE host.def  ##############################################
pwd
%define rhbuild %(hostname | grep -q "\\.redhat\\.com$" && echo 1 || echo 0)
cat > xc/config/cf/host.def << EOF
%if %{rhbuild}
#define XFree86CustomVersion \
    "Red Hat Linux release: %{version}-%{release}"
%else
#define XFree86CustomVersion \
    "Custom Build: %{version}-%{release}"
%endif

#define BuilderString "Build Host: %(hostname)\n"

#define LinuxDistribution	LinuxRedHat
    
%if %{DebuggableBuild}
#define BuildDebug		YES
/* #define XFree86Devel		YES */
/* #define DoLoadableServer	NO */
%endif

#define BootstrapCFlags		$RPM_OPT_FLAGS -pipe
#define DefaultGcc2i386Opt	$RPM_OPT_FLAGS -pipe
#define DefaultGcc2AxpOpt	$RPM_OPT_FLAGS -pipe -Wa,-m21164a

%if %{ParallelBuild}
#define ParallelMakeFlags	-j%(getconf _NPROCESSORS_ONLN)
/* This one seems to fuckup on GLU, possibly a conflict with HJL's patch */
/*#define HasParallelMake		YES  */
%endif

#define NeedModuleRanlib	YES
#define ModuleRanlibCmd		RanlibCmd

#define LinkGLToUsrInclude	NO
#define LinkGLToUsrLib		NO

#define ForceNormalLib		YES

/* Disable joystick support because it is totally broken in XFree86 4.x, at
   least up to and including 4.1.0.  Use native OS joystick support instead. */
#define JoystickSupport		NO

%ifarch s390 s390x
#define HasAgpGart              NO
%else
#define HasAgpGart              YES
%endif

#define HasPam			YES
#define HasPamMisc		YES
#define HasZlib			YES
/* Use Freetype 2, but we have our own - so don't build it */
#define HasFreetype2		YES

#define HasLinuxInput		YES
#define HasMMXSupport		YES
#define Has3DNowSupport		YES
/* #define HasKatmaiSupport         YES */

#define XtermWithI18N		YES

%if %{BuildTdfx}
#define HasGlide3		YES
#define Glide3LibName		glide3
#define Glide3IncDir		$RPM_BUILD_ROOT/usr/include/glide3
%endif

#define BuildFonts              YES
#define BuildSpeedoFonts        YES
#define BuildCyrillicFonts      YES
/* #define BuildISO8859_1Fonts     YES */
#define BuildISO8859_2Fonts	YES
#define BuildISO8859_3Fonts	NO
#define BuildISO8859_4Fonts	NO
#define BuildISO8859_5Fonts	BuildCyrillicFonts
/* #define BuildISO8859_6Fonts	NO  */
#define BuildISO8859_7Fonts	YES 
/* #define BuildISO8859_8Fonts	NO  */
#define BuildISO8859_9Fonts	YES
#define BuildISO8859_10Fonts	NO
#define BuildISO8859_11Fonts	NO
#define BuildISO8859_12Fonts	NO
#define BuildISO8859_13Fonts	NO
#define BuildISO8859_14Fonts	NO
#define BuildISO8859_15Fonts	YES

#define BuildXF86MiscExt        YES
#define BuildHtmlManPages       NO

%ifarch s390 s390x
/* DRI modules */
#define BuildXF86DRI			NO
#define BuildServer			YES
#define XVirtualFramebufferServer	YES
#define XnestServer			YES
%else
/* DRI modules */
#define BuildXF86DRI            YES
%endif
#define BuildXF86DRM            NO

%ifarch s390 s390x ppc ppc64
#define BuildSuperProbe			NO
%else
#define BuildSuperProbe         YES
%endif

#define BuildXinerama           YES
#define BuildXineramaLibrary    YES
#define BuildXF86DGA            YES

#define UseXserverWrapper	YES
#define UseUtempter		YES
#define UseInternalMalloc       NO
#define UseMatroxHal            NO

#define UseConfDirForXkb           NO
#define UseConfDirForAppDefaults   NO

#undef  DefaultUserPath
#define DefaultUserPath		/usr/local/bin:/bin:/usr/bin
#undef  DefaultSystemPath
#define DefaultSystemPath	/usr/local/sbin:/sbin:/usr/sbin:/bin:/usr/bin

#define AdmDir              /var/log
#define LbxproxyDir         /etc/X11/lbxproxy
#define ProxyManagerDir     /etc/X11/proxymngr
#define ServerConfigDir     /etc/X11/xserver
#define XdmDir              /etc/X11/xdm
#define XConfigDir          /etc/X11
#define XinitDir            /etc/X11/xinit

%ifarch alpha
#define XF86CardDrivers mga nv tga s3virge sis rendition \
			neomagic i740 tdfx cirrus tseng trident chips apm \
			fbdev ati vga v4l glint
%endif

%ifarch ia64
/* #define XF86CardDrivers mga nv s3virge sis rendition i740 \
 *			tdfx v4l fbdev glint ati vga 
 */
#define XF86CardDrivers mga nv tdfx v4l fbdev glint ati vga 
%endif

%ifarch ppc ppc64
#define XF86CardDrivers mga glint s3virge sis savage \
                        ati trident chips fbdev \
                        DevelDrivers vga \
                        XF86OSCardDrivers XF86ExtraCardDrivers
%endif

#define DriverManDir    \$(MANSOURCEPATH)4
#define DriverManSuffix 4x /* use just one tab or cpp will die */
#define MiscManDir      \$(MANSOURCEPATH)7
#define MiscManSuffix   7x /* use just one tab or cpp will die */

EOF


##########  BUILD  ##################################################

%build
[ "$RPM_BUILD_ROOT" != "/" ] && rm -rf $RPM_BUILD_ROOT
# Remove unnecessary stuff...  DO NOT MOVE THIS
find . -name CVS -type d | xargs rm -rf
#find . -name .cvsignore -type f |xargs rm -f

%if %{ParallelBuild}
numprocs=$(( $(egrep -c ^cpu[0-9]+ /proc/stat || :) * 2 ))
[ "$numprocs" = "0" ] && numprocs=1
echo "PARALLEL MAKE ENABLED: numprocs=$numprocs"
%else
numprocs=1
%endif

#####  GLIDE 3 BUILD  ###############################################
# This Glide3 mess was a big bad idea(TM) to include into XFree86.spec  ;o)
# Fortunately, it got removed back to its own RPM in a later release.

%if %{BuildGlide3}
{
    pushd Glide3 ; libtoolize --copy --force; aclocal ; automake ; autoconf

    mkdir build-5 ; cd build-5
    CFLAGS="$RPM_OPT_FLAGS" ../configure --enable-fx-debug=no \
        --enable-fx-glide-hw=h5 --enable-fx-dri-build --prefix=/usr
    make -f makefile.autoconf all
    cd ..

    #FIXME Perhaps do a make clean here to try and fix problem with Voodoo 4/5
    
    mkdir build-3 ; cd build-3
    CFLAGS="$RPM_OPT_FLAGS" ../configure --enable-fx-debug=no \
        --enable-fx-glide-hw=h3 --enable-fx-dri-build --prefix=/usr
    make -f makefile.autoconf all
    cd ..
    # Removed $RPM_BUILD_ROOT from GLIDELIB path (May 2, 2001 mharris)
    gcc -o glidelink %{SOURCE13} $RPM_OPT_FLAGS \
        -DGLIDELIB=\"/usr/lib/libglide3.so.%{Glide3Libver}\" \
        -lkudzu -lpci

    #####  GLIDE 3 INSTALL  #########################################
    # Moved here because XFree86 needs Glide installed to build tdfx module
    #pushd Glide3
    mkdir -p $RPM_BUILD_ROOT/usr/sbin
    install -m 755 glidelink $RPM_BUILD_ROOT/usr/sbin/glidelink
    cd build-3
    make -f makefile.autoconf install DESTDIR=$RPM_BUILD_ROOT
    # Hack
    mkdir -p $RPM_BUILD_ROOT/usr/lib/glide3
    mv $RPM_BUILD_ROOT/usr/lib/libglide3.so.%{Glide3Libver} \
        $RPM_BUILD_ROOT/usr/lib/glide3/libglide3-v3.so

    install -m 755 ../build-5/h5/glide3/src/.libs/libglide3.so.%{Glide3Libver} \
        $RPM_BUILD_ROOT/usr/lib/glide3/libglide3-v5.so
    # FIXME: Point to v3 by default
    ln -snf glide3/libglide3-v3.so \
        $RPM_BUILD_ROOT/usr/lib/libglide3.so.%{Glide3Libver}        
    # ldconfig doesn't like this?
    ln -snf libglide3.so.%{Glide3Libver} $RPM_BUILD_ROOT/usr/lib/libglide3.so
    #popd
    #####  END GLIDE 3 INSTALL  #####################################
    popd
}
%endif
#####  END GLIDE 3 BUILD  ############################################


%if %{DebuggableBuild}
makeg World -C xc WORLDOPTS= FAST=1
%else
make World -C xc WORLDOPTS= FAST=1
%endif


##########  INSTALL  #################################################
%install
# Enable set -x if VerboseBuild is enabled
%{!?VerboseBuild:set -x}

mkdir -p $RPM_BUILD_ROOT{/usr/{include,lib},/etc/{pam.d,security/console.apps}}
install -c -m 644 %{SOURCE3} $RPM_BUILD_ROOT/etc/pam.d/xserver
install -c -m 644 %{SOURCE4} $RPM_BUILD_ROOT/etc/pam.d/xdm
touch $RPM_BUILD_ROOT/etc/security/console.apps/xserver

make DESTDIR=$RPM_BUILD_ROOT install install.man -C xc

# FIXME: Can MESA stuff be disabled with Imake instead?
# Clean out Mesa stuff
   rm -rf $RPM_BUILD_ROOT%{_x11includedir}/GL
   rm -f  $RPM_BUILD_ROOT/usr/X11R6/lib/libGL* \
          $RPM_BUILD_ROOT/usr/X11R6/lib/libOSMesa.*

# point this to Xwrapper, not XFree86
ln -snf Xwrapper $RPM_BUILD_ROOT%{_x11bindir}/X

# WARNING:  The following program 'chatr' is used after the X server is
#           built to modify the generated binary to work correctly.  It is
#           an ugly hack, which should be temporary until a better fix is
#           available.  <notting>
%if %{with_chatr_hack_for_ia64}
gcc -o chatr %{SOURCE25}
./chatr -E $RPM_BUILD_ROOT%{_x11bindir}/XFree86
%endif

# Install sample XF86Config
%ifnarch s390 s390x
cp xc/programs/Xserver/hw/xfree86/XF86Config $RPM_BUILD_ROOT/etc/X11/
%endif

# we now provide a backwards compatible link for color-xterm/nxterm
pushd $RPM_BUILD_ROOT%{_x11bindir} ; ln -f xterm nxterm ; popd

# Explicitly create X authdir
mkdir -m 700 -p $RPM_BUILD_ROOT/var/lib/xdm/authdir

# We install our own config file for the xfs package
mkdir -p $RPM_BUILD_ROOT/etc/X11/fs
install -c -m 644 %{SOURCE6} $RPM_BUILD_ROOT/etc/X11/fs/config

mkdir -p $RPM_BUILD_ROOT/etc/rc.d/init.d
install -c -m 755 %{SOURCE5} $RPM_BUILD_ROOT/etc/rc.d/init.d/xfs

# FIXME: Can Imake do this?  Fix up symlinks
{
   mkdir -p $RPM_BUILD_ROOT/usr/{bin,include,lib}
   ln -sf ../X11R6/include/X11 $RPM_BUILD_ROOT/usr/include/X11
   ln -sf ../X11R6/include/DPS $RPM_BUILD_ROOT/usr/include/DPS

# This can probably go away in next major release
%ifnarch s390 s390x
   ln -snf ../../../../etc/X11/XF86Config \
      $RPM_BUILD_ROOT/usr/X11R6/lib/X11/XF86Config
%endif
}

# Backward compatibility symlink
ln -sf ../../usr/X11R6/lib/X11/xkb $RPM_BUILD_ROOT/etc/X11

# strip the crap that's safe to strip
%if ! %{DebuggableBuild}
{
# Old strip code, commented out in 4.1.0-39.2 to enable 7.3 style builds
# with useful symbol content.
#    set +x
#    strip --strip-unneeded -R .comment $RPM_BUILD_ROOT%{_x11bindir}/* || :
#    strip -R .comment $RPM_BUILD_ROOT/usr/X11R6/lib/*.so* || :

    set +x
    # Strip ELF binary executables of debug symbols and .comment section
    for file in $(find $RPM_BUILD_ROOT -type f -perm +0111 -exec file {} \; | \
                    grep -v ' shared object,' | \
                    sed -n -e 's/^\(.*\):[  ]*ELF.*, not stripped/\1/p')
    do
        strip --strip-debug -R .comment $file || :
    done
    # Strip shared libraries of .comment section, and all unneeded symbols
    strip --strip-unneeded -R .comment $RPM_BUILD_ROOT%{_x11libdir}/*.so.* || :
    strip --strip-unneeded -R .comment $RPM_BUILD_ROOT%{_libdir}/*.so.* || :
}
%endif

# symlink shared libs
{
    pushd $RPM_BUILD_ROOT/usr/X11R6/lib
    for lib in *.so.*; do ln -sf $lib ${lib%.so*}.so ; done
    popd
}

# FIXME: XFree86 font stuff is changing bigtime in 4.0.99.x, this needs to be
# examined in detail.
(
    export LD_LIBRARY_PATH="${LD_LIBRARY_PATH}:$RPM_BUILD_ROOT/usr/X11R6/lib"
    pushd $RPM_BUILD_ROOT%{_x11fontdir}/misc
    bzcat %{SOURCE8} | tar -xf -

    # Xlat9-10x20.bdf is included in XFree-4.0.2 under a different
    # name now so we don't include it here anymore.
    $RPM_BUILD_ROOT%{_x11bindir}/bdftopcf -t Xlat9-8x14.bdf \
        |gzip -9 > 8x14-ISO8859-15.pcf.gz
    $RPM_BUILD_ROOT%{_x11bindir}/bdftopcf -t Xlat9-9x16.bdf \
        |gzip -9 > 9x16-ISO8859-15.pcf.gz
            
    rm -f Xlat9-10x20.bdf Xlat9-8x14.bdf Xlat9-9x16.bdf
    popd
)

# Strip out all fonts.dir files from font directories as they should
# not be included in the packaging but should be generated at install
# time instead.
rm -f $(find $RPM_BUILD_ROOT%{_x11fontdir} -name 'fonts.dir') || :

# Make sure all manpage dirs exist and are owned by XFree86-libs
mkdir -m 755 -p $RPM_BUILD_ROOT%{_x11mandir}/man{1,2,3,4,5,6,7,8} || :

# FIXME: (Imakeable?) Remove GLw manpages since we don't ship libGLw (#41791)
# If we enable GLw in Mesa package, we should put the manpages back.
#rm -f $RPM_BUILD_ROOT%{_x11mandir}/man3*/GLw*.3*

# for ghost config file
touch $RPM_BUILD_ROOT/etc/X11/XF86Config-4

rm -f $RPM_BUILD_ROOT/etc/X11/XftConfig
cp %{SOURCE20} $RPM_BUILD_ROOT/etc/X11/XftConfig

# hack fix bug #49990
%ifnarch %{ix86} alpha
rm -f $RPM_BUILD_ROOT/usr/X11R6/lib/libxrx.*
%endif

######################################################################
#########  SCRIPT SECTION  ###########################################
######################################################################

%triggerpostun -- XFree86
{
%ifarch s390 s390x
  for dir in lbxproxy proxymngr rstart ; do
%else
  for dir in lbxproxy proxymngr rstart xserver ; do
%endif
    if [ -d /usr/X11R6/lib/X11/$dir ] ; then
      mv -f /usr/X11R6/lib/X11/$dir /etc/X11/ 2>/dev/null || :
    fi
    [ ! -L /usr/X11R6/lib/X11/$dir ] && \
      ln -snf ../../../../etc/X11/$dir /usr/X11R6/lib/X11/$dir || :
  done
} &> /dev/null || :

%pre
{
  XKB_DIR=/usr/X11R6/lib/X11/xkb/compiled
  if [ ! -L $XKB_DIR -a -d $XKB_DIR ]; then
    mkdir -p /var/lib/xkb
    mv -f $XKB_DIR /var/lib/xkb/
    ln -sf ../../../../../var/lib/xkb $XKB_DIR
  fi
} &> /dev/null || :

%post
{
%ifarch s390 s390x
  for dir in lbxproxy proxymngr rstart ; do
%else
  for dir in lbxproxy proxymngr rstart xserver ; do
%endif
    [ ! -L /usr/X11R6/lib/X11/$dir -a ! -d /usr/X11R6/lib/X11/$dir ] && \
      ln -snf ../../../../etc/X11/$dir /usr/X11R6/lib/X11/$dir || :
  done
# FIXME: Make it only run mkfontdir in dirs that have fonts in them.
# Build fonts.dir files for all font dirs in this package.  (exclude the local dir)
  for fontdir in 100dpi 75dpi CID Speedo Type1 misc latin2/{75dpi,100dpi} ;do
    %__mkfontdir %{_x11fontdir}/$fontdir || :
  done
  /usr/sbin/chkfontpath -q -a %{_x11fontdir}/75dpi:unscaled || :
  /usr/sbin/chkfontpath -q -a %{_x11fontdir}/100dpi:unscaled || :
  /usr/sbin/chkfontpath -q -a %{_x11fontdir}/latin2/75dpi:unscaled || :
  /usr/sbin/chkfontpath -q -a %{_x11fontdir}/latin2/100dpi:unscaled || :
  /usr/sbin/chkfontpath -q -a %{_x11fontdir}/misc:unscaled || :
  /usr/sbin/chkfontpath -q -a %{_x11fontdir}/Speedo || :
  /usr/sbin/chkfontpath -q -a %{_x11fontdir}/Type1 || :
} &> /dev/null || :

%postun
# Rebuild fonts.dir when uninstalling package. (exclude the local dir)
{
  if [ "$1" = "0" ]; then
    for fontdir in 100dpi 75dpi CID Speedo Type1 misc latin2/{75dpi,100dpi} ;do
      %__mkfontdir %{_x11fontdir}/$fontdir || :
    done
  fi
} &> /dev/null || :

%pre xdm
{
  # The dir /etc/X11/xdm/authdir moved to /var/lib/xdm/authdir and was replaced
  # by a symlink.  Upgrades from Red Hat Linux 6.x and earlier to any new
  # release with XFree86-4.0.x fail without the following. (fixes bug #32574)
  if [ ! -L /etc/X11/xdm/authdir -a -d /etc/X11/xdm/authdir ]; then
    mkdir -p /var/lib/xdm 2>/dev/null && \
    mv -f /etc/X11/xdm/authdir /var/lib/xdm/ 2>/dev/null && \
    ln -sf ../../../var/lib/xdm/authdir /etc/X11/xdm/authdir 2>/dev/null || :
  fi
}
         
%post libs
{
  grep "^/usr/X11R6/lib$" /etc/ld.so.conf &> /dev/null
  [ $? -ne 0 ] && echo "/usr/X11R6/lib" >> /etc/ld.so.conf
%if %{BuildGlide3}
  /usr/sbin/glidelink
%endif
  /sbin/ldconfig
}

%postun libs
{
  if [ "$1" = "0" ]; then
    grep -v "^/usr/X11R6/lib$" /etc/ld.so.conf > /etc/ld.so.conf.new
    # preserve permissions
    cat /etc/ld.so.conf.new > /etc/ld.so.conf
    rm -f /etc/ld.so.conf.new
  fi
  /sbin/ldconfig
}

%verifyscript libs
{
  echo -n "Looking for /usr/X11R6/lib in /etc/ld.so.conf... "
  if ! grep "^/usr/X11R6/lib$" /etc/ld.so.conf > /dev/null; then
    echo "missing"
    echo "/usr/X11R6/lib missing from /etc/ld.so.conf" >&2
  else
    echo "found"
  fi
}

##### xfs scripts ####################################################
%pre xfs
{
  /usr/sbin/useradd -c "X Font Server" -r -s /bin/false -u 43 \
                    -d /etc/X11/fs xfs
} &> /dev/null || :

%post xfs
{
  /sbin/chkconfig --add xfs
# FIXME: What an unmaintainable mess.  ;o) There almost has to be a cleaner
# way of doing this.  If not, it needs to be figured out and documented to
# avoid confusion.
  use_unix=
  for config in /etc/X11/XF86Config /etc/X11/XF86Config-4 ; do
    if [ -f $config ] && grep -q "unix/:" $config &> /dev/null; then
      use_unix=1
    fi
    if [ -f $config ] && grep -q "unix/:-1" $config &> /dev/null; then
      rm -f $config.new $config.rpmsave
      sed "s#unix/:-1#unix/:7100#g" $config > $config.new
      cp -f $config $config.rpmsave
      cat $config.new > $config
      rm -f $config.new
    fi
    if [ -f $config ] && grep -q "unix/:" $config &> /dev/null && \
      grep -q "%{_x11fontdir}/TrueType" $config &> /dev/null ; then \
	sed "s|FontPath[ ]*\"%{_x11fontdir}/TrueType\"|#FontPath \"%{_x11fontdir}/TrueType\"|g" $config > $config.new
      cat $config.new > $config
      rm -f $config.new
    fi
  done
  if [ -n "$use_unix" ] && ! grep -q "no-listen" /etc/X11/fs/config &> /dev/null;then
    echo -e "# don't listen on tcp by default\nno-listen = tcp\n" >> /etc/X11/fs/config
  fi
}

%preun xfs
{
  if [ "$1" = "0" ]; then
    /sbin/chkconfig --del xfs || :
    /usr/sbin/userdel xfs 2>/dev/null || :
    /usr/sbin/groupdel xfs 2>/dev/null || :
    service xfs stop &> /dev/null || :
  fi
}

%postun xfs
{
  if [ "$1" -ge "1" ]; then
    service xfs condrestart &> /dev/null || :
  fi
}

%post 75dpi-fonts
{
    %__mkfontdir %{_x11fontdir}/75dpi
    /usr/sbin/chkfontpath -q -a %{_x11fontdir}/75dpi:unscaled
} &> /dev/null || :

%post 100dpi-fonts
{
    %__mkfontdir %{_x11fontdir}/100dpi
    /usr/sbin/chkfontpath -q -a %{_x11fontdir}/100dpi:unscaled
} &> /dev/null || :

%post ISO8859-2-75dpi-fonts
{
    %__mkfontdir %{_x11fontdir}/75dpi
    /usr/sbin/chkfontpath -q -a %{_x11fontdir}/75dpi:unscaled
} &> /dev/null || :

%post ISO8859-2-100dpi-fonts
{
    %__mkfontdir %{_x11fontdir}/100dpi
    /usr/sbin/chkfontpath -q -a %{_x11fontdir}/100dpi:unscaled
} &> /dev/null || :

%post ISO8859-9-75dpi-fonts
{
    %__mkfontdir %{_x11fontdir}/75dpi
    /usr/sbin/chkfontpath -q -a %{_x11fontdir}/75dpi:unscaled
} &> /dev/null || :

%post ISO8859-9-100dpi-fonts
{
    %__mkfontdir %{_x11fontdir}/100dpi
    /usr/sbin/chkfontpath -q -a %{_x11fontdir}/100dpi:unscaled
} &> /dev/null || :

%post ISO8859-15-75dpi-fonts
{
    %__mkfontdir %{_x11fontdir}/75dpi
    /usr/sbin/chkfontpath -q -a %{_x11fontdir}/75dpi:unscaled
} &> /dev/null || :
    

%post ISO8859-15-100dpi-fonts
{
    %__mkfontdir %{_x11fontdir}/100dpi
    /usr/sbin/chkfontpath -q -a %{_x11fontdir}/100dpi:unscaled
} &> /dev/null || :

%post cyrillic-fonts
{
    %__mkfontdir %{_x11fontdir}/cyrillic
    /usr/sbin/chkfontpath -q -a %{_x11fontdir}/cyrillic:unscaled
} &> /dev/null || :

%postun 75dpi-fonts
{
  if [ "$1" = "0" ]; then
    %__mkfontdir %{_x11fontdir}/75dpi
  fi
} &> /dev/null || :

%postun 100dpi-fonts
{
  if [ "$1" = "0" ]; then
    %__mkfontdir %{_x11fontdir}/100dpi
  fi
} &> /dev/null || :

%postun ISO8859-2-75dpi-fonts
{
  if [ "$1" = "0" ]; then
    %__mkfontdir %{_x11fontdir}/75dpi
  fi
}

%postun ISO8859-2-100dpi-fonts
{
  if [ "$1" = "0" ]; then
    %__mkfontdir %{_x11fontdir}/100dpi
  fi
} &> /dev/null || :

%postun ISO8859-9-75dpi-fonts
{
  if [ "$1" = "0" ]; then
    %__mkfontdir %{_x11fontdir}/75dpi
  fi
} &> /dev/null || :

%postun ISO8859-9-100dpi-fonts
{
  if [ "$1" = "0" ]; then
    %__mkfontdir %{_x11fontdir}/100dpi
  fi
} &> /dev/null || :

%postun ISO8859-15-75dpi-fonts
{
  if [ "$1" = "0" ]; then
    %__mkfontdir %{_x11fontdir}/75dpi
  fi
} &> /dev/null || :

%postun ISO8859-15-100dpi-fonts
{
  if [ "$1" = "0" ]; then
    %__mkfontdir %{_x11fontdir}/100dpi
  fi
} &> /dev/null || :

%postun cyrillic-fonts
{
  if [ "$1" = "0" ]; then
    %__mkfontdir %{_x11fontdir}/cyrillic
  fi
} &> /dev/null || :


########## FILES SECTION #############################################

%files
%defattr(-,root,root)
%dir /etc/X11/lbxproxy
%dir /etc/X11/proxymngr
%dir /etc/X11/rstart

%ifnarch s390 s390x
%dir /etc/X11/xinit
%dir /etc/X11/xserver
%config(noreplace) %verify(not md5 size mtime) /etc/X11/XF86Config
%endif
%ghost %config(missingok,noreplace) %verify(not md5 size mtime) /etc/X11/XF86Config-4

%dir /etc/X11/xsm
%config /etc/X11/lbxproxy/AtomControl
%config /etc/X11/proxymngr/pmconfig
%config /etc/X11/rstart/*
# %config /etc/X11/xinit/xinitrc We have a separate xinitrc package
%config /etc/X11/xsm/system.xsm
%ifnarch s390 s390x
%config /etc/X11/xserver/*
%endif
#%config /etc/X11/XftConfig
# Changed back to 'noreplace' to fix bug #53103
%config(noreplace) /etc/X11/XftConfig

%dir /usr/X11R6/lib/modules
%dir /usr/X11R6/lib/modules/codeconv
%dir /usr/X11R6/lib/modules/extensions
%dir /usr/X11R6/lib/modules/fonts
%ifnarch s390 s390x
%dir /usr/X11R6/lib/modules/input
%endif

%ifnarch s390 s390x
%dir /usr/X11R6/lib/modules/linux
%endif

%dir /usr/X11R6/lib/X11/etc
%ghost /usr/X11R6/lib/X11/lbxproxy
%ghost /usr/X11R6/lib/X11/proxymngr
%ghost /usr/X11R6/lib/X11/rstart
%ifnarch s390 s390x
%ghost /usr/X11R6/lib/X11/xserver
%endif
%dir /usr/X11R6/lib/X11/xkb
%config /usr/X11R6/lib/X11/app-defaults/*
%dir /var/lib/xkb
%config %attr(0644,root,root) /etc/pam.d/xserver
%config(missingok) /etc/security/console.apps/xserver
/var/lib/xkb/README
%ifnarch s390 s390x ppc ppc64
%{_x11bindir}/SuperProbe
%endif
%{_x11bindir}/X
%ifnarch s390 s390x
%attr(711,root,root) %{_x11bindir}/XFree86
%endif
%attr(4711,root,root) %{_x11bindir}/Xwrapper
%{_x11bindir}/Xmark
%{_x11bindir}/Xprt
# FIXME: Should these be disabled for real on ppc?
%ifnarch s390 s390x ppc ppc64
%{_x11bindir}/pcitweak
%{_x11bindir}/scanpci
%endif
%{_x11bindir}/appres
%{_x11bindir}/atobm
%{_x11bindir}/bdftopcf
%{_x11bindir}/bdftruncate.pl
%{_x11bindir}/bitmap
%{_x11bindir}/bmtoa
%{_x11bindir}/dga
%{_x11bindir}/dpsexec
%{_x11bindir}/dpsinfo
%{_x11bindir}/editres
%{_x11bindir}/iceauth
%{_x11bindir}/lbxproxy
%{_x11bindir}/lndir
%{_x11bindir}/makepsres
%{_x11bindir}/makestrs
%{_x11bindir}/mergelib
%{_x11bindir}/mkcfm
%{_x11bindir}/mkdirhier
%{_x11bindir}/nxterm
%{_x11bindir}/proxymngr
%{_x11bindir}/resize
%{_x11bindir}/revpath
%{_x11bindir}/rstart
%{_x11bindir}/rstartd
%{_x11bindir}/sessreg
%{_x11bindir}/setxkbmap
%{_x11bindir}/showrgb
%{_x11bindir}/smproxy
%ifnarch s390 s390x
%{_x11bindir}/startx
%endif
%{_x11bindir}/texteroids
%{_x11bindir}/xauth
%{_x11bindir}/xcmsdb
%{_x11bindir}/xconsole
%{_x11bindir}/xcutsel
%{_x11bindir}/xdpyinfo
%ifnarch s390 s390x
%{_x11bindir}/xf86config
%endif
%{_x11bindir}/xfindproxy
%{_x11bindir}/xftcache
%{_x11bindir}/xfwp
%{_x11bindir}/xgamma
%{_x11bindir}/xhost
%ifnarch s390 s390x
%{_x11bindir}/xinit
%endif
%{_x11bindir}/xkbbell
%{_x11bindir}/xkbcomp
%{_x11bindir}/xkbevd
%{_x11bindir}/xkbprint
%{_x11bindir}/xkbvleds
%{_x11bindir}/xkbwatch
%{_x11bindir}/xlsatoms
%{_x11bindir}/xlsclients
%{_x11bindir}/xlsfonts
# Not included - obsolete
#%{_x11bindir}/xmh
%{_x11bindir}/xmodmap
%{_x11bindir}/xon
%{_x11bindir}/xprop
%{_x11bindir}/xrdb
%{_x11bindir}/xrefresh
%{_x11bindir}/xset
%{_x11bindir}/xsetmode
%{_x11bindir}/xsetpointer
%{_x11bindir}/xsetroot
%{_x11bindir}/xsm
%{_x11bindir}/xstdcmap
%{_x11bindir}/xterm
%if %{BuildXterm3d}
%{_x11bindir}/xterm3d
%endif
%{_x11bindir}/xvidtune
%{_x11bindir}/xwd
%{_x11bindir}/xwud
%ifnarch s390 s390x
%dir /usr/X11R6/lib/X11/doc
%docdir /usr/X11R6/lib/X11/doc
/usr/X11R6/lib/X11/doc/*
/usr/X11R6/lib/modules/linux/*
%endif
%ifarch %{ix86} alpha
/usr/X11R6/lib/modules/*.uc
%endif

# XFree86 server modules
/usr/X11R6/lib/modules/*.a
/usr/X11R6/lib/modules/codeconv/*
%ifarch %{ix86} alpha ia64
/usr/X11R6/lib/modules/dri
%endif
/usr/X11R6/lib/modules/extensions/*
/usr/X11R6/lib/modules/fonts/*
%ifnarch s390 s390x
/usr/X11R6/lib/modules/input/*
%endif

# This is provided by the Xconfigurator package
#/usr/X11R6/lib/X11/Cards
# This should probably be moved to Xconfigurator also
%ifnarch s390 s390x
/usr/X11R6/lib/X11/Options
/usr/X11R6/lib/X11/XF86Config
# Junk config file for PC98
#/usr/X11R6/lib/X11/XF86Config.98
#/usr/X11R6/lib/X11/XF86Config.eg
%endif
/usr/X11R6/lib/X11/XftConfig

# FONTS
%dir %{_x11fontdir}
%dir %{_x11fontdir}/100dpi
%dir %{_x11fontdir}/75dpi
%dir %{_x11fontdir}/CID
%{_x11fontdir}/CID/*
%ifnarch ia64 alpha
%dir %{_x11fontdir}/PEX
%{_x11fontdir}/PEX/*
%endif
%dir %{_x11fontdir}/encodings
%{_x11fontdir}/encodings/*
# The local dir is not populated by X, so no we only claim ownership
# of the dir.
%dir %{_x11fontdir}/local
%dir %{_x11fontdir}/misc
%{_x11fontdir}/misc/*
%dir %{_x11fontdir}/util
%{_x11fontdir}/util/*
%dir %{_x11fontdir}/Speedo
%{_x11fontdir}/Speedo/*
%dir %{_x11fontdir}/Type1
%{_x11fontdir}/Type1/*
#%config(noreplace) %{_x11fontdir}/Type1/fonts.scale

%dir /usr/X11R6/lib/X11/app-defaults
%ifnarch s390 s390x
/usr/X11R6/lib/X11/etc/*
/usr/X11R6/lib/X11/xinit
%endif
/usr/X11R6/lib/X11/xkb/*
/etc/X11/xkb
%dir /usr/X11R6/lib/X11/x11perfcomp
/usr/X11R6/lib/X11/x11perfcomp/*
/usr/X11R6/lib/X11/xsm
%ifnarch s390 s390x ppc ppc64
%{_x11mandir}/man1/SuperProbe.1*
%{_x11mandir}/man1/XFree86.1*
%endif
%{_x11mandir}/man1/Xserver.1*
%{_x11mandir}/man1/Xmark.1*
%{_x11mandir}/man1/appres.1*
%{_x11mandir}/man1/atobm.1*
%{_x11mandir}/man1/bdftopcf.1*
%{_x11mandir}/man1/bitmap.1*
%{_x11mandir}/man1/bmtoa.1*
%{_x11mandir}/man1/dga.1*
%{_x11mandir}/man1/dpsexec.1*
%{_x11mandir}/man1/dpsinfo.1*
%{_x11mandir}/man1/editres.1*
%{_x11mandir}/man1/iceauth.1*
%{_x11mandir}/man1/lbxproxy.1*
%ifarch %{ix86} alpha
%{_x11mandir}/man1/libxrx.1*
%endif
%{_x11mandir}/man1/lndir.1*
%{_x11mandir}/man1/makedepend.1*
%{_x11mandir}/man1/makepsres.1*
%{_x11mandir}/man1/makestrs.1*
%{_x11mandir}/man1/mkcfm.1*
%{_x11mandir}/man1/mkdirhier.1*
%{_x11mandir}/man1/oclock.1*
%ifnarch s390 s390x ppc ppc64
%{_x11mandir}/man1/pcitweak.1*
%endif
%{_x11mandir}/man1/proxymngr.1*
%{_x11mandir}/man1/resize.1*
%{_x11mandir}/man1/revpath.1*
%{_x11mandir}/man1/rstart.1*
%{_x11mandir}/man1/rstartd.1*
%ifnarch s390 s390x ppc ppc64
%{_x11mandir}/man1/scanpci.1*
%endif
%{_x11mandir}/man1/sessreg.1*
%{_x11mandir}/man1/setxkbmap.1*
%{_x11mandir}/man1/showrgb.1*
%{_x11mandir}/man1/smproxy.1*
%ifnarch s390 s390x
%{_x11mandir}/man1/startx.1*
%endif
%{_x11mandir}/man1/texteroids.1*
%{_x11mandir}/man1/twm.1*
%{_x11mandir}/man1/xauth.1*
%{_x11mandir}/man1/xcmsdb.1*
%{_x11mandir}/man1/xconsole.1*
%{_x11mandir}/man1/xcutsel.1*
%{_x11mandir}/man1/xdpyinfo.1*
%ifnarch s390 s390x
%{_x11mandir}/man1/xf86config.1*
%endif
%{_x11mandir}/man1/xfindproxy.1*
%{_x11mandir}/man1/xftcache.1*
%{_x11mandir}/man1/xfwp.1*
%{_x11mandir}/man1/xgamma.1*
%{_x11mandir}/man1/xhost.1*
%ifnarch s390 s390x
%{_x11mandir}/man1/xinit.1*
%endif
%{_x11mandir}/man1/xkbcomp.1*
%{_x11mandir}/man1/xkbevd.1*
%{_x11mandir}/man1/xkbprint.1*
%{_x11mandir}/man1/xkill.1*
%{_x11mandir}/man1/xlogo.1*
%{_x11mandir}/man1/xlsatoms.1*
%{_x11mandir}/man1/xlsclients.1*
%{_x11mandir}/man1/xlsfonts.1*
# Not included - obsolete
#%{_x11mandir}/man1/xmh.1*
%{_x11mandir}/man1/xmodmap.1*
%{_x11mandir}/man1/xon.1*
%{_x11mandir}/man1/xprop.1*
%{_x11mandir}/man1/xrdb.1*
%{_x11mandir}/man1/xrefresh.1*
%{_x11mandir}/man1/xset.1*
%{_x11mandir}/man1/xsetmode.1*
%{_x11mandir}/man1/xsetpointer.1*
%{_x11mandir}/man1/xsetroot.1*
%{_x11mandir}/man1/xsm.1*
%{_x11mandir}/man1/xstdcmap.1*
%{_x11mandir}/man1/xterm.1*
%{_x11mandir}/man1/xvidtune.1*
%{_x11mandir}/man1/xwd.1*
%{_x11mandir}/man1/xwud.1*
%ifnarch s390 s390x
%{_x11mandir}/man4/*
%{_x11mandir}/man5/*
%endif
%{_x11mandir}/man7/*
# Drivers
%ifnarch s390 s390x
%dir /usr/X11R6/lib/modules/drivers
/usr/X11R6/lib/modules/drivers/*
%endif

%files tools
%defattr(-,root,root)
%{_x11bindir}/beforelight
%{_x11bindir}/glxinfo
%{_x11bindir}/ico
%{_x11bindir}/listres
%{_x11bindir}/mkhtmlindex
%{_x11bindir}/oclock
%{_x11bindir}/showfont
%{_x11bindir}/ucs2any.pl
%{_x11bindir}/viewres
%{_x11bindir}/x11perf
%{_x11bindir}/x11perfcomp
%{_x11bindir}/xbiff
%{_x11bindir}/xcalc
%{_x11bindir}/xclipboard
%{_x11bindir}/xclock
%{_x11bindir}/xditview
%{_x11bindir}/xedit
%{_x11bindir}/xev
%{_x11bindir}/xeyes
%{_x11bindir}/xfd
%{_x11bindir}/xfontsel
%{_x11bindir}/xgc
%{_x11bindir}/xieperf
# no need to be SUID
%attr(755,root,root) %{_x11bindir}/xload
%{_x11bindir}/xmag
%{_x11bindir}/xman
%{_x11bindir}/xmessage
%{_x11bindir}/xvinfo
%{_x11bindir}/xwininfo
%{_x11bindir}/xlogo
%{_x11bindir}/xkill
/usr/X11R6/lib/X11/xman.help
%{_x11mandir}/man1/beforelight.1*
%{_x11mandir}/man1/glxinfo.1*
%{_x11mandir}/man1/ico.1*
%{_x11mandir}/man1/listres.1*
%{_x11mandir}/man1/showfont.1*
%{_x11mandir}/man1/viewres.1*
%{_x11mandir}/man1/x11perf.1*
%{_x11mandir}/man1/x11perfcomp.1*
%{_x11mandir}/man1/xbiff.1*
%{_x11mandir}/man1/xcalc.1*
%{_x11mandir}/man1/xclipboard.1*
%{_x11mandir}/man1/xclock.1*
%{_x11mandir}/man1/xditview.1*
%{_x11mandir}/man1/xedit.1*
%{_x11mandir}/man1/xev.1*
%{_x11mandir}/man1/xeyes.1*
%{_x11mandir}/man1/xfd.1*
%{_x11mandir}/man1/xfontsel.1*
%{_x11mandir}/man1/xgc.1*
%{_x11mandir}/man1/xieperf.1*
%{_x11mandir}/man1/xload.1*
%{_x11mandir}/man1/xmag.1*
%{_x11mandir}/man1/xman.1*
%{_x11mandir}/man1/xmessage.1*
%{_x11mandir}/man1/xvinfo.1*
%{_x11mandir}/man1/xwininfo.1*


%files xfs
%defattr(-,root,root)
%dir /etc/X11/fs
# Changed back to 'noreplace' to fix bug #53103
%config(noreplace) %verify(not md5 size mtime) /etc/X11/fs/config
%config /etc/rc.d/init.d/xfs
%{_x11bindir}/xfsinfo
%{_x11bindir}/fslsfonts
%{_x11bindir}/fstobdf
# Probably should move mkfontdir to another package.
%{_x11bindir}/mkfontdir
%{_x11bindir}/xfs
/usr/X11R6/lib/X11/fs
%{_x11mandir}/man1/xfs.1*
%{_x11mandir}/man1/mkfontdir.1*
%{_x11mandir}/man1/xfsinfo.1*
%{_x11mandir}/man1/fslsfonts.1*
%{_x11mandir}/man1/fstobdf.1*


%files twm
%defattr(-,root,root)
%dir /etc/X11/twm
%config /etc/X11/twm/system.twmrc
%{_x11bindir}/twm
/usr/X11R6/lib/X11/twm


%files xdm
%defattr(-,root,root)
%dir /etc/X11/xdm
/etc/X11/xdm/authdir
%dir /etc/X11/xdm/pixmaps
/etc/X11/xdm/pixmaps/*
%config /etc/X11/xdm/Xservers
%config /etc/X11/xdm/Xresources
%config /etc/X11/xdm/Xwilling
%config /etc/X11/xdm/chooser
%config  %attr(0644,root,root) /etc/pam.d/xdm
%{_x11bindir}/xdm
/usr/X11R6/lib/X11/xdm
%{_x11mandir}/man1/xdm.1*
%dir /var/lib/xdm
%dir %attr(0700,root,root) /var/lib/xdm/authdir


%files devel
%defattr(-,root,root)
%dir %{_x11includedir}/DPS
%dir %{_x11includedir}/X11
%dir %{_x11includedir}/X11/ICE
%ifnarch ia64 alpha
%dir %{_x11includedir}/X11/PEX5
%endif
%dir %{_x11includedir}/X11/PM
%dir %{_x11includedir}/X11/SM
%dir %{_x11includedir}/X11/Xaw
%dir %{_x11includedir}/X11/Xft
%dir %{_x11includedir}/X11/Xmu
%dir %{_x11includedir}/X11/bitmaps
%{_x11includedir}/X11/bitmaps/*
%ifnarch s390 s390x
%dir %{_x11includedir}/X11/pixmaps
%{_x11includedir}/X11/pixmaps/*
%endif
%dir %{_x11includedir}/X11/extensions
%{_x11includedir}/X11/extensions/*.h
%dir %{_x11includedir}/X11/fonts
%{_x11includedir}/X11/fonts/*.h
%dir %{_x11includedir}/X11/fonts/codeconv
%{_x11includedir}/X11/fonts/codeconv/*.h
%dir /usr/X11R6/lib/X11/config
%{_x11bindir}/cxpm
%{_x11bindir}/gccmakedep
%{_x11bindir}/imake
%{_x11bindir}/makedepend
%{_x11bindir}/makeg
%{_x11bindir}/pswrap
%{_x11bindir}/rman
%{_x11bindir}/sxpm
%{_x11bindir}/xmkmf
%ifnarch s390 s390x
%{_x11includedir}/*.h
%endif
%{_x11includedir}/DPS/*.h
%{_x11includedir}/X11/*.h
%{_x11includedir}/X11/ICE/*.h
%ifnarch ia64 alpha
%{_x11includedir}/X11/PEX5/*.h
%endif
%{_x11includedir}/X11/PM/*.h
%{_x11includedir}/X11/SM/*.h
%{_x11includedir}/X11/Xaw/*
%{_x11includedir}/X11/Xft/*
%{_x11includedir}/X11/Xmu/*.h
/usr/X11R6/lib/*.so
/usr/X11R6/lib/*.a
/usr/X11R6/lib/X11/config/*
/usr/include/X11
/usr/include/DPS
%{_x11mandir}/man1/cxpm.1*
%{_x11mandir}/man1/imake.1*
%{_x11mandir}/man1/makeg.1*
%{_x11mandir}/man1/pswrap.1*
%{_x11mandir}/man1/rman.1*
%{_x11mandir}/man1/sxpm.1*
%{_x11mandir}/man1/xmkmf.1*
%{_x11mandir}/man3/*

%files libs
%defattr(-,root,root)
# All manpage dirs owned by libs package to guarantee they are owned by some
# installed package because everything pretty much depends on libs being there
%dir %{_x11mandir}/man1
%dir %{_x11mandir}/man2
%dir %{_x11mandir}/man3
%dir %{_x11mandir}/man4
%dir %{_x11mandir}/man5
%dir %{_x11mandir}/man6
%dir %{_x11mandir}/man7
%dir %{_x11mandir}/man8
%dir /usr/X11R6/lib/X11
%dir /usr/X11R6/lib/X11/locale
/usr/X11R6/lib/X11/locale/*
# These files (XErrorDB, XKeysymDB, rgb.txt) moved here in 4.1.0-43 for
# AS 2.1 enhancement request - bugzilla bug (#79488)
/usr/X11R6/lib/X11/XErrorDB
/usr/X11R6/lib/X11/XKeysymDB
/usr/X11R6/lib/X11/rgb.txt
# Shared libraries:  /usr/X11R6/lib/lib*.so.* might be better in the long run
# except for arch specific stuff, but it shouldn't be built in the first place.
# libxrx.so can probably be disabled with imake "SharedLibxrx NO" instead
/usr/X11R6/lib/libICE.so.*
%ifnarch ia64 alpha
/usr/X11R6/lib/libPEX5.so.*
%endif
/usr/X11R6/lib/libSM.so.*
/usr/X11R6/lib/libX11.so.*
/usr/X11R6/lib/libXIE.so.*
/usr/X11R6/lib/libXaw.so.*
/usr/X11R6/lib/libXext.so.*
/usr/X11R6/lib/libXfont.so.*
/usr/X11R6/lib/libXft.so.*
/usr/X11R6/lib/libXi.so.*
/usr/X11R6/lib/libXmu.so.*
/usr/X11R6/lib/libXmuu.so.*
/usr/X11R6/lib/libXp.so.*
/usr/X11R6/lib/libXpm.so.*
/usr/X11R6/lib/libXrender.so.*
/usr/X11R6/lib/libXt.so.*
/usr/X11R6/lib/libXtst.so.*
/usr/X11R6/lib/libdps.so.*
/usr/X11R6/lib/libdpstk.so.*
/usr/X11R6/lib/libpsres.so.*
%ifarch %{ix86} alpha
/usr/X11R6/lib/libxrx.so.*
%endif
#### Glide 3 ###
%if %{BuildGlide3}
/usr/lib/glide3
/usr/lib/libglide3.so*
/usr/sbin/glidelink
%endif
#### END Glide 3 ###


%files 75dpi-fonts
%defattr(-,root,root)
%dir %{_x11fontdir}/75dpi
# ISO-10646-1 fonts 
%{_x11fontdir}/75dpi/UTBI__[0-9][0-9].pcf.gz
%{_x11fontdir}/75dpi/UTB___[0-9][0-9].pcf.gz
%{_x11fontdir}/75dpi/UTI___[0-9][0-9].pcf.gz
%{_x11fontdir}/75dpi/UTRG__[0-9][0-9].pcf.gz
%{_x11fontdir}/75dpi/courB[0-9][0-9].pcf.gz
%{_x11fontdir}/75dpi/courBO[0-9][0-9].pcf.gz
%{_x11fontdir}/75dpi/courO[0-9][0-9].pcf.gz
%{_x11fontdir}/75dpi/courR[0-9][0-9].pcf.gz
%{_x11fontdir}/75dpi/helvB[0-9][0-9].pcf.gz
%{_x11fontdir}/75dpi/helvBO[0-9][0-9].pcf.gz
%{_x11fontdir}/75dpi/helvO[0-9][0-9].pcf.gz
%{_x11fontdir}/75dpi/helvR[0-9][0-9].pcf.gz
%{_x11fontdir}/75dpi/luBIS[0-9][0-9].pcf.gz
%{_x11fontdir}/75dpi/luBS[0-9][0-9].pcf.gz
%{_x11fontdir}/75dpi/luIS[0-9][0-9].pcf.gz
%{_x11fontdir}/75dpi/luRS[0-9][0-9].pcf.gz
%{_x11fontdir}/75dpi/lubB[0-9][0-9].pcf.gz
%{_x11fontdir}/75dpi/lubBI[0-9][0-9].pcf.gz
%{_x11fontdir}/75dpi/lubI[0-9][0-9].pcf.gz
%{_x11fontdir}/75dpi/lubR[0-9][0-9].pcf.gz
%{_x11fontdir}/75dpi/lutBS[0-9][0-9].pcf.gz
%{_x11fontdir}/75dpi/lutRS[0-9][0-9].pcf.gz
%{_x11fontdir}/75dpi/ncenB[0-9][0-9].pcf.gz
%{_x11fontdir}/75dpi/ncenBI[0-9][0-9].pcf.gz
%{_x11fontdir}/75dpi/ncenI[0-9][0-9].pcf.gz
%{_x11fontdir}/75dpi/ncenR[0-9][0-9].pcf.gz
%{_x11fontdir}/75dpi/timB[0-9][0-9].pcf.gz
%{_x11fontdir}/75dpi/timBI[0-9][0-9].pcf.gz
%{_x11fontdir}/75dpi/timI[0-9][0-9].pcf.gz
%{_x11fontdir}/75dpi/timR[0-9][0-9].pcf.gz
# ISO-8859-1 fonts
%{_x11fontdir}/75dpi/char*.pcf.gz
%{_x11fontdir}/75dpi/term14.pcf.gz
%{_x11fontdir}/75dpi/termB14.pcf.gz
%{_x11fontdir}/75dpi/*-ISO8859-1.pcf.gz
# Misc non-ISO-foo fonts.
%{_x11fontdir}/75dpi/symb[0-9][0-9].pcf.gz
%{_x11fontdir}/75dpi/tech14.pcf.gz
%{_x11fontdir}/75dpi/techB14.pcf.gz
%ghost %verify(not md5 size mtime) %{_x11fontdir}/75dpi/encodings.dir
%verify(not md5 size mtime) %config(noreplace) %{_x11fontdir}/75dpi/fonts.alias


# This contains ISO-10646-1 and ISO-8859-1 font encodings, and a few miscs.
%files 100dpi-fonts
%defattr(-,root,root)
%dir %{_x11fontdir}/100dpi
# ISO-10646-1 fonts 
%{_x11fontdir}/100dpi/UTBI__[0-9][0-9].pcf.gz
%{_x11fontdir}/100dpi/UTB___[0-9][0-9].pcf.gz
%{_x11fontdir}/100dpi/UTI___[0-9][0-9].pcf.gz
%{_x11fontdir}/100dpi/UTRG__[0-9][0-9].pcf.gz
%{_x11fontdir}/100dpi/courB[0-9][0-9].pcf.gz
%{_x11fontdir}/100dpi/courBO[0-9][0-9].pcf.gz
%{_x11fontdir}/100dpi/courO[0-9][0-9].pcf.gz
%{_x11fontdir}/100dpi/courR[0-9][0-9].pcf.gz
%{_x11fontdir}/100dpi/helvB[0-9][0-9].pcf.gz
%{_x11fontdir}/100dpi/helvBO[0-9][0-9].pcf.gz
%{_x11fontdir}/100dpi/helvO[0-9][0-9].pcf.gz
%{_x11fontdir}/100dpi/helvR[0-9][0-9].pcf.gz
%{_x11fontdir}/100dpi/luBIS[0-9][0-9].pcf.gz
%{_x11fontdir}/100dpi/luBS[0-9][0-9].pcf.gz
%{_x11fontdir}/100dpi/luIS[0-9][0-9].pcf.gz
%{_x11fontdir}/100dpi/luRS[0-9][0-9].pcf.gz
%{_x11fontdir}/100dpi/lubB[0-9][0-9].pcf.gz
%{_x11fontdir}/100dpi/lubBI[0-9][0-9].pcf.gz
%{_x11fontdir}/100dpi/lubI[0-9][0-9].pcf.gz
%{_x11fontdir}/100dpi/lubR[0-9][0-9].pcf.gz
%{_x11fontdir}/100dpi/lutBS[0-9][0-9].pcf.gz
%{_x11fontdir}/100dpi/lutRS[0-9][0-9].pcf.gz
%{_x11fontdir}/100dpi/ncenB[0-9][0-9].pcf.gz
%{_x11fontdir}/100dpi/ncenBI[0-9][0-9].pcf.gz
%{_x11fontdir}/100dpi/ncenI[0-9][0-9].pcf.gz
%{_x11fontdir}/100dpi/ncenR[0-9][0-9].pcf.gz
%{_x11fontdir}/100dpi/timB[0-9][0-9].pcf.gz
%{_x11fontdir}/100dpi/timBI[0-9][0-9].pcf.gz
%{_x11fontdir}/100dpi/timI[0-9][0-9].pcf.gz
%{_x11fontdir}/100dpi/timR[0-9][0-9].pcf.gz
# ISO-8859-1 fonts
%{_x11fontdir}/100dpi/char*.pcf.gz
%{_x11fontdir}/100dpi/term14.pcf.gz
%{_x11fontdir}/100dpi/termB14.pcf.gz
%{_x11fontdir}/100dpi/*-ISO8859-1.pcf.gz
# Misc non-ISO-foo fonts.
%{_x11fontdir}/100dpi/symb[0-9][0-9].pcf.gz
%{_x11fontdir}/100dpi/tech14.pcf.gz
%{_x11fontdir}/100dpi/techB14.pcf.gz
%ghost %verify(not md5 size mtime) %{_x11fontdir}/100dpi/encodings.dir
%verify(not md5 size mtime) %config(noreplace) %{_x11fontdir}/100dpi/fonts.alias


%files ISO8859-2-75dpi-fonts
%defattr(-,root,root)
%{_x11fontdir}/75dpi/*-ISO8859-2.pcf.gz
#%config(noreplace) %{_x11fontdir}/75dpi/fonts.*

%files ISO8859-2-100dpi-fonts
%defattr(-,root,root)
%{_x11fontdir}/100dpi/*-ISO8859-2.pcf.gz
#%config(noreplace) %{_x11fontdir}/100dpi/fonts.*

%files ISO8859-9-75dpi-fonts
%defattr(-,root,root)
%{_x11fontdir}/75dpi/*-ISO8859-9.pcf.gz
#%config(noreplace) %{_x11fontdir}/75dpi/fonts.*

%files ISO8859-9-100dpi-fonts
%defattr(-,root,root)
%{_x11fontdir}/100dpi/*-ISO8859-9.pcf.gz
#%config(noreplace) %{_x11fontdir}/100dpi/fonts.*

%files ISO8859-15-75dpi-fonts
%defattr(-,root,root)
%{_x11fontdir}/75dpi/*-ISO8859-15.pcf.gz
#%config(noreplace) %{_x11fontdir}/75dpi/fonts.*

%files ISO8859-15-100dpi-fonts
%defattr(-,root,root)
%{_x11fontdir}/100dpi/*-ISO8859-15.pcf.gz
#%config(noreplace) %{_x11fontdir}/100dpi/fonts.*

%files cyrillic-fonts
%defattr(-,root,root)
%dir %{_x11fontdir}/cyrillic
%{_x11fontdir}/cyrillic/*.gz
#%config(noreplace) %{_x11fontdir}/cyrillic/fonts.*

%ifnarch s390 s390x
%files doc
%defattr(-,root,root)
%doc xc/doc/hardcopy/*
%endif

%files Xnest
%defattr(-,root,root)
%{_x11bindir}/Xnest
%{_x11mandir}/man1/Xnest.1*

%files Xvfb
%defattr(-,root,root)
%{_x11bindir}/Xvfb
%{_x11mandir}/man1/Xvfb.1*

%ifnarch ia64 s390 s390x
%files xf86cfg
%defattr(-,root,root)
%{_x11bindir}/xf86cfg
%{_x11mandir}/man1/xf86cfg.1*
%endif


%clean
[ "$RPM_BUILD_ROOT" != "/" ] && rm -rf $RPM_BUILD_ROOT 


########## CHANGELOG SECTION #########################################
%changelog
* Sat May 24 2003 Mike A. Harris <mharris@redhat.com> 4.1.0-49.RHEL
- Rebuild 4.1.0-49 unmodified as 4.1.0-49.RHEL for Red Hat Enterprise Linux
  2.1 AS/AW/ES/WS

* Wed May 14 2003 Mike A. Harris <mharris@redhat.com> 4.1.0-49
- Added XFree86-4.1.0-redhat-version-change-detection.patch to detect X server
  version skew changes in any patches that we are applying, and fail the
  build.  When version skew is detected, XFree86-4.1.0-redhat-lock-version.patch
  gets applied prior to the detection patch in order to lock the version at
  4.1.0, so that the X server does not advertise itself as a beta product
  due to VERSION_SNAP being used.

* Sun Apr 20 2003 Mike A. Harris <mharris@redhat.com> 4.1.0-48
- Updated savage driver to Tim Roberts 1.1.27t driver which fixes numerous
  bugs and adds support for newer hardware.  Also fixes (#71973)

* Mon Apr 14 2003 Mike A. Harris <mharris@redhat.com> 4.1.0-47.1
- Added XFree86-4.2.1-redhat-bug-report-address-update.patch to have server
  crash messages direct people where to file bug reports

* Wed Apr  2 2003 Mike A. Harris <mharris@redhat.com> 4.1.0-47
- Added XFree86-4.1.0-makefile-fastbuild.patch to speed up building
- Disabled chatr hack and enabled PROT_EXEC patch for ia64

* Tue Apr  1 2003 Mike A. Harris <mharris@redhat.com> 4.1.0-46.2
- Added XFree86-4.1.0-ati-radeon-pagesize-fixes.patch to cleanup pagesize
  assumptions which effect ia64 and alpha architectures
- Added XFree86-4.1.0-elf-loader-mmap-prot-exec.patch on ia64, which should
  fix the ELF loader to mmap memory allocated for modules using PROT_EXEC,
  allowing us to get rid of the super ugly chatr.c hack

* Tue Apr  1 2003 Mike A. Harris <mharris@redhat.com> 4.1.0-46.1
- The following patches were in 4.1.0-45.x but I removed them in order to do
  the 4.1.0-46 release to meet other requirements, and added them back now
- Added XFree86-4.1.0-xterm-DECUDK-security-fix.patch to fix security issue
  indicated in [CAN-2003-0071]
- Added XFree86-4.2.1-xterm-can-2003-0063.patch to fix [CAN-2003-0063]
- Added XFree86-4.1.0-xdm-auth_dir.patch

* Tue Apr  1 2003 Mike A. Harris <mharris@redhat.com> 4.1.0-46
- Added XFree86-4.1.0-ia64-nv-quadro-980-380-unsupported.patch for minimal 2D
  operation for Quadro 4 980/380 on ia64 arch, however we do not officially
  support this hardware (#81783)
- Minor updates to XFree86-4.1.0-ia64-nv-quadro-900-750-500-unsupported.patch
  for maintainability

* Wed Mar  5 2003 Mike A. Harris <mharris@redhat.com> 4.1.0-45
- Added XFree86-4.1.0-ati-r128-full-chipset-support.patch to provide support
  for all remaining previously unsupported ATI Rage 128 chips to Red Hat
  Advanced Server 2.1, and Red Hat Linux 7.1/7.2 customers, which is a
  combination of XFree86-4.1.0-ati-r128-SM-PP-PR-TF-TL-TR.patch, a few bits
  and pieces of other pre-existing patches in our packaging, and a backport
  of relevant pieces of my r128 support patch that got into 4.3.0
- Removed Build_7x macro, since it is no longer needed anymore due to other
  fixes that have been made

* Wed Mar  5 2003 Mike A. Harris <mharris@redhat.com> 4.1.0-44.mh.4
- Split up XFree86-4.1.0-ati-radeon-ve-update.patch into 3 pieces, leaving the
  original "radeon" driver bits in the patch, and relocating the Rage 128
  Pro Ultra related bits to XFree86-4.1.0-ati-r128-pro-ultra-update.patch,
  and atichip.[ch]/atiprobe.c updates to XFree86-4.1.0-ati-atichip-atiprobe-update.patch
- Merged the r128 SM/PP/PR and pro-ultra patches into one new combo patch
  XFree86-4.1.0-ati-r128-SM-PP-PR-TF-TL-TR.patch for easier future maintenance

* Tue Mar  4 2003 Mike A. Harris <mharris@redhat.com> 4.1.0-44.mh.3
- Added XFree86-4.1.0-ati-r128-PP-fix.patch to fix problem reported by IHVs
- Added XFree86-4.1.0-ati-xf86PciInfo.h-update.patch to centralize all of the
  ATI related updates to xf86PciInfo.h for maintainability

* Fri Feb 14 2003 Mike A. Harris <mharris@redhat.com> 4.1.0-44.mharris.2
- Added drmRadeonResetCP to XFree86-4.1.0-ati-radeon-unresolved-drm-symbols.patch
  that I just noticed in my X server log

* Tue Feb 11 2003 Mike A. Harris <mharris@redhat.com> 4.1.0-44.mharris.1
- Added XFree86-4.2.99.901-xauth-diskfull.patch which fixes a bug where xauth
  may write an incomplete .xauth file and delete the old one if there is
  insufficient disk space (Harald Hoyer - #84036)

* Tue Dec 24 2002 John Dennis <jdennis@redhat.com> 4.1.0-44
- Use XFree86-4.1.0-ia64-disable-int10-on-hp-zx1.patch patch provided by
  John Fujii to disable int10 loading on Hewlett Packard ZX1 ia64 boxen
- Disable previous XFree86-4.1.0-ati-skip-int10-on-hp-ia64.patch patch as it
  is obsolted by above patch

* Wed Dec 18 2002 Mike A. Harris <mharris@redhat.com> 4.1.0-43
- The files (XErrorDB, XKeysymDB, rgb.txt) moved from XFree86 to XFree86-libs
  subpackage in 4.1.0-43 for AS 2.1 enhancement request - bugzilla bug (#79488)

* Tue Dec 17 2002 John Dennis <jdennis@redhat.com> 4.1.0-42
- Fix for running xdm on Longs Peak causes spontaneous reboot (#73889)

* Fri Dec 13 2002 Mike A. Harris <mharris@redhat.com> 4.1.0-41.1
- Add alpha to ifnarch in file lists for PEX related files

* Fri Dec  6 2002 Mike A. Harris <mharris@redhat.com> 4.1.0-41
- Removed the rpm macros BuildPEX, BuildXIE, and WithExternalMesa, as they are
  always built now anyway in all supported Red Hat Linux releases except ia64
- Added XFree86-4.1.0-ati-skip-int10-on-hp-ia64.patch to runtime detect HP
  ia64 machines which int10 does not work on, and disable it <jdennis@redhat.com>
- Updated XFree86-4.1.0-disable-merge-constants-on-modules.patch to fix a
  bug in the patch which caused it to not work properly <jdennis@redhat.com>
- Removed DisableModuleStringMerging macro, and BuildRequires: gcc >= 2.96-93
  since we now autodetect and disable it via backported patches from 4.2.0
- Updated XFree86-4.1.0-timestamp-monotonicity.patch to build properly
- Updated XFree86-4.1.0-mkfontdir-perms.patch to fix bug that caused it to
  not work correctly

* Tue Nov 26 2002 Mike A. Harris <mharris@redhat.com> 4.1.0-40.1
- Backport XFree86-4.2.1-timestamp-monotonicity.patch to guarantee the X server
  timestamps increase monotonically internally (#63509)

* Thu Nov 16 2002 Mike A. Harris <mharris@redhat.com> 4.1.0-40
- Updated all bitmap font post scripts to use :unscaled instead of not.  This
  is a backport fix from later releases to get rid of ugly scaled bitmap fonts.
- Removed the BuildKernelDRMModules, and BuildVoodoo options as they were
  not implemented, and are just cluttering the spec file.
- Backported _x11dir, etc. macros from 4.2.99.2 specfile, did cleanups for
  _x11mandir, _x11includedir, _x11bindir, _x11fontdir
- Changed the default build stripping policy to that used in XFree86 4.2.0
  packaging in Red Hat Linux 7.3 and later.  This allows for easier debugging
  and troubleshooting of the X server without having to do a full debug build.
- Backported Imake changes from from 4.2.0 which autodetect if gcc has
  string merging enhancements or not, disabling them on module builds if
  present with -fno-merge-constants.  This is present, but currently disabled
  pending more testing.
- Added BuildRequires: autoconf, automake, libtool for Glide3 *sigh*

* Thu Nov 16 2002 Mike A. Harris <mharris@redhat.com> 4.1.0-39
- Removed patch 1100 which was not being applied anyway (NoStringMerge) as we
  are accomplishing the same task in host.def right now
- Re-enabled int10 in host.def on ia64 because Intel Tiger hardware needs this.
  Whatever is broken on HP boxen WRT int10 will likely need to be fixed.
- Disabled XFree86-4.1.0-int10-hplso.patch as it is just senseless
- Split XFree86-4.1.0-ia64-nv-memory-barrier-v2.patch into 2 separate patches,
  one with the mem barrier stuff (XFree86-4.1.0-ia64-nv-memory-barrier.patch)
  and another (XFree86-4.1.0-ia64-nv-riva-ia64-stability.patch) with the rest
  of the riva fixes for ia64
- Added comments to the chatr.c hack so that people who read the spec file
  trying to figure out why their hand built X server does not work when
  manually compiling it in the build dir with minor fixes during development.
- Removed conditional pam-devel hacks which were for my personal use and no
  longer required, in order to clean things up a bit
- Reorganized Obsoletes: section of specfile
- Removed various old dead patches that were disabled, and hence unneeded
  anymore, just to further clean up the package for long term maintenance.
- Changed all BuildPrereq to BuildRequires for consistency and moved them all
  to the same location in the specfile
- Added BuildRequires: libtool, as beehive did not have libtool installed in
  buildroot *baffle*

* Fri Sep  6 2002 Mike A. Harris <mharris@redhat.com> 4.1.0-38
- (ia64) Disabled previous nv-memory-barrier patch and added version 2 of
  the patch for bug (#70572)
- (ia64) Added Quadro4 700/900 XGL support patch XFree86-4.1.0-ia64-nv-quadro-4.patch
  from John Fujii at Hewlett Packard with patch from bug (#73566)

* Tue Sep  3 2002 Mike A. Harris <mharris@redhat.com> 4.1.0-37
- (ia64) Added XFree86-4.1.0-ia64-nv-memory-barrier.patch to partially fix
  Itanium MCA on Nvidia with "nv" driver in bug (#70572)

* Tue Sep  3 2002 Mike A. Harris <mharris@redhat.com> 4.1.0-36
- Updated workaround for MCA on ia64 by disabling SolidTwoPointLine on all
  Radeon hardware after new information from Kevin Martin that the Radeon does
  not implement this in a way that complies to the X specifications.

* Fri Aug 30 2002 Mike A. Harris <mharris@redhat.com> 4.1.0-35
- Created a workaround for Radeon PCI causing Machine Check Architecture on
  ia64 in SolidTwoPointLine 2D acceleration MMIO codepath (#71701)
  
* Thu Aug 29 2002 Mike A. Harris <mharris@redhat.com> 4.1.0-34
- Disabled video drivers on ia64 which we do not have hardware for and do not
  know if they work at all, in order to minimize what we can realistically
  provide support for.  In future releases, the drivers will be re-enabled
  for testing with hardware that is available, and working drivers will be
  left enabled.
- Updated License tag to be "MIT" instead of "XFree86"

* Tue Aug 21 2002 Mike A. Harris <mharris@redhat.com> 4.1.0-33
- Added XFree86-4.1.0-ia64-vgaHW-memory-barrier.patch to fix an MCA on ia64
  machines in the vgaHW lib (#72061)

* Mon Jul 29 2002 Mike A. Harris <mharris@redhat.com> 4.1.0-32
- Fixed ATI Radeon startup problem on ia64 by disabling int10 support via Imake
  for ia64.  The ia64 Linux distro from HP does not have int10 enabled on
  ia64.

* Thu Jul 25 2002 Mike A. Harris <mharris@redhat.com> 4.1.0-31
- New Radeon CP engine 2D accel code patch added to improve 2D acceleration
  performance on ia64.  A few other enhancements and bugfixes are also present.

* Tue Jul  2 2002 Bill Nottingham <notting@redhat.com> 4.1.0-30
- Added chatr.c which is an ugly hack used to fix X on ia64 to deal with
  non-executable stacks

* Thu Jun 13 2002 Mike A. Harris <mharris@redhat.com> 4.1.0-29
- Fixed a few specfile issues previously missed

* Tue Jun 11 2002 Mike A. Harris <mharris@redhat.com> 4.1.0-28
- Added 4 patches from Hewlett Packard for ia64 (XFree86-4.1.0-int10-hplso.patch,
  XFree86-4.1.0-pci-hplso.patch, XFree86-4.1.0-primpci-hplso.patch,
  XFree86-4.1.0-ps2-hplso.patch

* Fri Jun  7 2002 Mike A. Harris <mharris@redhat.com> 4.1.0-27
- Fixed issues(TM)

* Sat Apr 27 2002 Mike A. Harris <mharris@redhat.com> 4.1.0-26
- Bump release to -26 and rebuild for alpha.  Otherwise unmodified from
  the -25 release.

* Thu Apr 18 2002 Mike A. Harris <mharris@redhat.com> 4.1.0-25
- Changed build time pam deps to pam-devel, which is met on both RHL 7.1
  and 7.2.
- Added drm-device-dir-perms to fix /dev/dri perms
- Added XFree86-4.1.0-misc-fixes-from-debian.patch which contains various
  very small unobtrusive fixes from Debian XFree86 4.1.0-14

* Thu Mar 28 2002 Mike A. Harris <mharris@redhat.com> 4.1.0-24
- Do not compress ulT1mo Type1 font files, aparently it breaks them.

* Mon Mar 11 2002 Mike A. Harris <mharris@redhat.com> 4.1.0-23
- Updated time-wraparound patch from bug (#60906) with smaller fix from
  Keith Packard.

* Fri Mar  8 2002 Mike A. Harris <mharris@redhat.com> 4.1.0-22
- Added fix for X server crash when server up for over 49 days and timer
  wraps around (#60906)

* Thu Mar  7 2002 Mike A. Harris <mharris@redhat.com> 4.1.0-21
- Added ati-mach64-rage-XL patch to fix bug for Dell, IBM (#58188)
- Fixed mitshm bug

* Thu Feb 21 2002 Mike A. Harris <mharris@redhat.com> 4.1.0-20
- Added ppc64 to ifarch/ifnarch wherever ppc was found
- Updated XFree86-4.1.0-sunffb-4.1.99-DPMSMode.patch from spot, and fixed
  specfile to apply it properly. (3500)
- Added XFree86-4.1.0-xkbcomp-alias.patch for sparc arches for spot

* Fri Feb 15 2002 Mike A. Harris <mharris@redhat.com> 4.1.0-19
- Added ifnarch to kernel-drm dependancy so platforms without DRI support
  (ppc/ppc64/sparc/sparc64/s390/s390x) do not end up with a needless dependancy.

* Fri Feb  8 2002 Mike A. Harris <mharris@redhat.com> 4.1.0-18
- Updated anyhose patch to the patch Deigo Novilla sent me from compaq
  compaq-alpha-101_anyhose-XFree86-rh410-8-200202041558, for the Alpha port.

* Tue Jan 29 2002 Mike A. Harris <mharris@redhat.com> 4.1.0-17
- Added Provides/Obsoletes Glide3-devel to XFree86-devel package.  Went
  unnoticed largely because barely anything requires Glide3-devel.  ;o)

* Mon Jan 28 2002 Mike A. Harris <mharris@redhat.com> 4.1.0-16
- Added XFree86-4.1.0-compaq-alpha-100_vga_en_on_invisible_host_bridge-XFree86-rh410-8-200201250722.patch
  of all eye-pokeoutageness from Compaq for Alpha.  ;o)
  
* Tue Jan 22 2002 Mike A. Harris <mharris@redhat.com> 4.1.0-15
- Added Conflicts XFree86-doc < 4.1.0-3 line to XFree86 main package because
  some files moved from XFree86-doc to XFree86 package in the 4.1.0 release.
  This causes a file conflict error to occur if someone upgrades manually or
  via up2date and does not update the new XFree86-doc package for some reason.

* Thu Dec 20 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-14.3
- Enhanced XftConfig to give better truetype font support

* Tue Dec 18 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-14
- Backed out previous ATI Radeon Mobility patches as they dont apply properly
  and are non-trivial to clean up.
- Skipped release -13 out of superstition

* Sat Dec 15 2001 Mike A. Harris <mharris@redhat.com>
- Added ifarchd sunffb-4.1.99-DPMSMode patch for sparc

* Tue Dec 11 2001 Mike A. Harris <mharris@redhat.com>
- Added patch 149 and 150 to fix various issues on ATI Radeon Mobility M6/M7

* Mon Dec 10 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-12
- Integrated whomping amounts of Alpha patches from Compaq 5000-5010

* Thu Dec  6 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-11
- Integrated PPC arch changes from streeter@redhat.com

* Wed Dec 05 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-10
- Integrated the Chinese gb18030 support patches received from yshao@redhat.com
- Reordered the DisableModuleStringMerging stuff in the specfile to be less
  confusing to people, and updated the comment explaining how to use it.
- Added PPC architecture to those not needing -fno-merge-constants for building

* Thu Nov 29 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-9
- Cleaned up some cosmetic issues in X server startup messages from
  updated stable branch patch

* Wed Nov 28 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-8
- Updated to latest xf-4_1-branch from XFree86 CVS to pick up many fixes
  but in particular, this one from XFree86 CHANGELOG:
   647. SECURITY: fix glyph clipping for large origin (Keith Packard).
        Reported to be remotly exploitable through konqueror or netscape
        by Georgi Guninski.
- Removed patches that are already integrated now including:
  XFree86-4.1.0-Xrender-required-libs.patch, XFree86-4.1.0-libXfont-put-eof.patch,
  XFree86-4.1.0-compose-iso8859-2.patch, XFree86-4.1.0-crash-message-fixup.patch
  
* Mon Nov 19 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-7
- Added ifarch s390 checks in trigger and post scripts to avoid messing
  with "xserver" symlinks, etc..  (#56215)

* Mon Nov 19 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-6.1
- Fixed that annoying Radeon hardware mouse cursor bug, where any mouse
  pointer that has a hotspot *NOT* on the left side of the pointer, caused
  the mouse to freeze up and jump around on left side of screen.
  XFree86-4.1.0-radeon-hardware-cursor-fix.patch
- When using Radeon with DRI disabled, X complains furiously about a tonne
  of unresolved DRM symbols.  This patch fixes it:
  XFree86-4.1.0-ati-radeon-unresolved-drm-symbols.patch
- Fixed ATI Radeon Xv code to display "ATI Radeon" instead of Rage 128

* Mon Nov  5 2001 Mike A. Harris <mharris@redhat.com>
- Added XFree-4.1.0-TridentCyber9525.patch to fix (#20659)
- Added XFree86-4.1.0-neomagic-dga.patch to fix (#52553)
- Added new entries to XftConfig for "console" and "fixed" to not antialias,
  which solves problems reported in konsole and other Qt applications.

* Thu Nov  1 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-6
- Integrated the Chinese gb18030 support patches received from yshao@redhat.com                                                                                                                      - Fixed XFree86-4.1.0-ati-pciids-cleanup.patch to give the correct PCI
  info for Radeon Mobility LW hardware that was incorrectly set to LY.
  This should fix some reported problems on Radeon Mobility M6/M7.
- Fixed specfile bug - allow-module-flags patch was surrounded by an ifnarch
  s390 instead of by DisableModuleStringMerging (#54959)

* Tue Oct 30 2001 Than Ngo <than@redhat.com>
- Added XFree86-4.1.0-cpp-s390x.patch which fixes a man-pages of size 0
  bug on s390 (#54927,#54932)

* Sat Oct 27 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-5
- Disabled VT switch patch from -4 release after feedback of regression
- Updated the Savage driver with Tim Roberts 1.1.20t driver, this should
  fix the reported bugs with Staroffice locking up X, and also video
  memory detection problems: (#31879)
- Added XFree86-4.1.0-keycodes-abnt2.patch to fix abnt2 support bug(#55128)

* Mon Oct  7 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-4
- Added patch to fix VT switch hangs that are hardware independant.  This
  should fix numerous reported VT switch bug reports.
- Fixed up host.def parallel make stuff.. HasParallelMake define is broken,
  and unneeded for now.

* Sat Oct  6 2001 Mike A. Harris <mharris@redhat.com>
- Removed __rmfontpath macro, and its usage, as well as the rpm 4.0.3 dep,
  because a lot of people were getting snagged on it, and it is questionable
  of the benefit of removing the fontpaths anyways, since it does not harm
  anything by leaving the font paths in config files really.
- Changed /lib/libpam reqs to pam-devel instead
- Commented the DisableModuleStringMerging specfile define, and moved to top
  of specfile where it is much more visible, as a lot of people have been
  getting snagged on this.

* Wed Oct  3 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-3.9
- Modified and unified the "make World" buildlines by removing all the
  buildflags, etc. from them, and moving them into proper Imake configuration
  variables.
- Added "-pipe" to default C compiler flags, as it should work on all
  architectures now.
- Various other specfile cleanups.
- Created support for ATI Rage 128 PP (1002:5050) XFree86-4.1.0-ati-r128-PP.patch
  
* Mon Sep 24 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-3.8
- Silenced some Glide3 compiler warnings with Glide3-redhat-cleanup-1.patch.

* Sun Sep 23 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-3.5
- Primary integration of changes in specfile to allow simple conditional
  build of fully debuggable modularized XFree86 packages.  This is done by
  enabling DebuggableBuild RPM macro at top of specfile, adding "dbg" to
  Release tag, and rebuilding.  The resulting RPM packages total in at 127Mb
  of data, as opposed to 55Mb or so regularly.  In order to debug this
  debuggable XFree86, a special patched version of gdb 5.0 is required, which
  is currently a work in progress based on a much older patch for gdb 4.18.

* Mon Sep 17 2001 Mike A. Harris <mharris@redhat.com>
- Changed xfs initscript to use find -cnewer instead of -newer to fix
  bug (#53737)

* Wed Sep  5 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-3 
- Reordered font paths in xfs catalogue to put 75dpi first, etc..
- fixed couple critical specfile bugs that have slipped through til now

* Tue Sep  4 2001 Mike A. Harris <mharris@redhat.com>
- Fixed fs/config bug (MF#53103) as well as doing the same for XftConfig

* Fri Aug 31 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-2
- Fixed a couple SHOULD-FIX bugs - fontpath order (SF#52413),
  metaSendsEscape bug (SF#49315)

* Wed Aug 29 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-1.1
- Added "Requires: kernel-drm = 4.1.0" so that a matching kernel RPM package
  is installed and DRI works properly.  (Brought up by mkj/arjan, and agreed
  upon by me)

* Tue Aug 28 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-1
- Added dont-build-pex-docs patch from Branden Robinson to disable building
  PEX documentation (deprecated and obsolete)
- Fix permissions on XftConfig, and other source files. (MF#52735)
- Bravely bumping version to 4.1.0-1
- Added xinerama-extmod patch for bug (#52842)

* Mon Aug 27 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-0.99.2
- Added Obsoletes: XFree86-ISO8859-2-Type1-fonts < 4.1.0, and provides
  ISO8859-2-Type1-fonts, to fix upgrade from 7.1, and prepare for future
  packaging.
- Removed (noreplace) from fs/config, I *want* it to replace.
  
* Sun Aug 26 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-0.99.1
- Completed font related fixups (hopefully)
- Added specfile buildroot install time removal of fonts.dir files as they
  should never ever be included in the RPM packaging, but generated at
  runtime instead.

* Fri Aug 24 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-0.20.5
- Added XFree86-4.1.0-ati-pciids-cleanup.patch, which includes misc
  cleanups to the PCI tables for ATI hardware.
- Added ati-radeon-dri-buildfix from notting@redhat.com which hopefully
  fixes bug (#51884)

* Tue Aug 21 2001 Mike A. Harris <mharris@redhat.com>
- Completed font screwup overhaul take1.

* Mon Aug 20 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-0.20.1
- Added XFree86-4.1.0-s3virge-mx.patch to fix some corruption issues on
  S3 Virge MX hardware.
- BuildPreReq: rpm >= 4.0.3  (parameterized macro fix)

* Sat Aug 18 2001 Mike A. Harris <mharris@redhat.com>
- Exclude XFree86 doc dir from, and add xdm pixmaps to s390 arch.

* Wed Aug 15 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-0.20.0
- Added xman-soelim-fix to fix bug (#51037).
- Modified cirrus-foobaroo patch to disable debug messages (#51179)
- Backed out an xfs change that breaks serving 3.3.6 servers.  Attempted
  workaround for (#)
- Disable ATI update patch to see if it fixes Radeon DRI bugs.

* Mon Aug 13 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-0.9.13
- Added XFree86-4.1.0-radeon-slowdownthere.patch to fix bug where ATI
  Radeon hangs on faster computers when VT switching.
- Created fix for mkfontdir to force permissions on newly created fonts.dir
  and encodings.dir files to be mode 644, fixes bug (#51636)
- Added fix for iso8859-2 compose file (affects Mozilla)
- Added patch to prevent X error messages from referencing log file if
  it has not yet been opened.
- Created support for ATI Rage 128 SM (Xpert2000), and added rage128-SM patch
  to fix (#34732,#51230,#50231) <mharris@redhat.com>
- Created XFree86-4.1.0-locale-alias-en_GB.patch to fix (#47247,51169)
- Moved video hardware documentation in /usr/X11R6/lib/X11/doc to main
  XFree86 package as that is where the drivers are (#50828)
- Updated XFree86 dependancy on Mesa to -> 3:3.4.2-5

* Thu Aug  9 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-0.9.12
- Synced with XFree86 stable branch to pick up upstream bugfixes
- Added support for Japanese 109 key USB keyboard

* Wed Aug  8 2001 Mike A. Harris <mharris@redhat.com>
- merged new changes into specfile
- added nn_NO, en_GB locale.alias support
- Added support to xfs.init for .ttc font files, and to use case
  insensitive regex when grepping for truetype fonts.  (#41169)

* Sun Aug  4 2001 Bill Nottingham <notting@redhat.com> 4.1.0-0.9.11
- port & apply necessary DRI fixes that fell out

* Thu Aug  2 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-0.9.10
- Added custom Red Hat XftConfig to fix AA font problems (#49937)
- Added RPM_BUILD_ROOT to ia64 libxrx removal.. ;o(

* Tue Jul 31 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-0.9.9
- Enabled "HasLinuxInput YES" to force wacom driver to get built with USB
  support with 2.4 kernel.  Fixes bug (#50453).
  
* Mon Jul 30 2001 Mike A. Harris <mharris@redhat.com>
- Attempted fix for (#50043) -frame option ignored when -id option used
  on xwd  (XFree86-4.1.0-xwd-frame-option.patch)
- Made XF86Config-4 outside ifnarch s390 as Bero claims s390 uses it.

* Thu Jul 26 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-0.9.8
- Added improved X startup messages for debugging purposes
- Updated patch148 from ATI plus 2 minor buildfixes

* Wed Jul 25 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-0.9.7
- Added XFree86-4.1.0-libXfont-put-eof.patch to fix bug (#48830) where
  the 100dpi/75dpi helvBO12.pcf.gz fonts were getting munged.
- Added XFree86-4.1.0-twm-coredumpfix.patch to fix (#49674)
- Added XFree86-4.1.0-cirrus-foobaroo-fix.patch from Egbert Eich to attempt
  to fix the Cirrus Logic problems.
- Fix libxrx problem on ia64 (#49990) by removing libxrx from non-x86/alpha

* Tue Jul 24 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-0.9.4
- Added XF86Config and XF86Config-4 as owned config files (latter ghosted)
- Fixed s390 Buildprereq on gcc by unnegating macro test
- Apply patch 3003 (64bit.patch) to all 64bit arch's.

* Tue Jul 24 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-0.9.3
- Worked around rpm parameterized macro processing bug that caused a problem
  with postun scripts - discovered by rpmlint.
- Reformatted all pre/post/postun/etc. scripts to be more readable and
  maintainable.
- Added patch8 to xterm resources to provide RFE (#48783)

* Mon Jul 23 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-0.9.2
- Added bison, zlib-devel as Buildprereqs - discovered on s390 by
  <Karsten.Hopp@redhat.de>
- Added ati-radeon-ve patch from ATI (patch148)
- Made Prereq's on /usr/sbin/chkfontpath instead of on chkfontpath

* Sun Jul 22 2001 Mike A. Harris <mharris@redhat.com>
- ifnarchd patch1013 for s390

* Wed Jul 18 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-0.9.1
- Created new macro __rmfontpath to be called from font package postun
  scripts to fix bug (#49243)

* Mon Jul 16 2001 Mike A. Harris <mharris@redhat.com>
- Added /usr/X11R6/man/man6, and other non existing manX dirs to XFree86-libs
  package so anything using them ends up having the dir owned by something.
- Removed unneeded shared lib stuff (Xv/Xxf86dga)

* Sun Jul 15 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-0.9.0
- Added BuildPrereq: gcc >= 2.96-93 to guarantee compiler used supports
  the -fno-merge-constants option
- Made External Mesa usage conditionalized via WithExternalMesa so that it is
  easy to rebuild XFree86 with/without using external Mesa, which will be the 
  default at some point in the future.

* Wed Jul 11 2001 Mike A. Harris <mharris@redhat.com>
- Explicitly state mkfontdir path in __mkfontdir macro (#48829)

* Tue Jul 10 2001 Mike A. Harris <mharris@redhat.com>
- Removed SharedLibXdmGreet from host.def, it is the same as default anyway
- Removed tcl and tk as buildprereq's, Bero says they're not needed anymore

* Tue Jul 10 2001 Tim Powers <timp@redhat.com> 4.1.0-0.8.6
- don't require XFree86-compat-libs in XFree86-libs

* Tue Jul 10 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-0.8.5
- Fixed missing requiredlibs on shared libXrender so that prelinking works.
- Built 4.1.0-0.8.4
- Woops, I left shared libXv and libXxf86dga on again by accident.
- Built 4.1.0-0.8.5
  
* Mon Jul  9 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-0.8.1
- Fixed up xdm pre script
- Fixed up missing Latin2 Type1 fonts, they are now in the fonts/Type1 dir
- Removed shared libXv.so and libXxf86dga.so at request of XFree86 team,
  and in conjunction with discussion with Debian X maintainer.

* Mon Jul  9 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-0.7.51
- Fixed ia64 Glide3 build failure.

* Sun Jul  8 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-0.7.50
- Merged with xf-4_1-branch to pick up stable bugfixes, and removed
  XFree86-4.1.0-redhat-glint-missing-symbols.patch, also Banshee
  ramtiming fix picked up from the update. 
  
* Fri Jul  6 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-0.7.12
- Really disabled string merging this time
- Added verify flag to /etc/X11/fs/config
- Disabled shared libraries Xv/xf86dga for standards compliance.  These
  libraries do not have a stable API and should not be shared.  It was
  a Bad Idea(tm) to ship these.

* Wed Jul  4 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-0.7.8
- Disabled string merging in modules using ModuleLdFlags in host.def
- Added WORLDOPTS= to make World to get rid of the "-k" passed to make so
  that failed X builds will fail immediately instead of continuing on.

* Mon Jul  2 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-0.7.6
- Phase 1 - Amalgamated all my local font related changes to get fonts
  working better in the new 4.1.0 release. Straightened out 75dpi/100dpi
  brokenness and split up packages.
- mkfontdir is now called in post(un)install scripts, and fonts.dir files are
  not installed as part of packages anymore because it was a bad broken idea
  to do so because these files should be generated, not provided.
- Added missing \ in main package post script

* Thu Jun 21 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-0.7.5
- Added customer requested custom 1152x864x85Hz modeline

* Sun Jun 17 2001 Mike A. Harris <mharris@redhat.com>
- Reworked all ISO8859-* font subpackages for 4.1.0.  fonts.dir is not
  included in the packages, rather it is generated at post install time.
- Refixed (#31618)

* Sat Jun 16 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-0.6.1
- More s390 cleanups

* Fri Jun 15 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-0.6.0
- Integrated s390 patches sent by Than from Oliver Paukstadt

* Sat Jun  9 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-0.5.6
- Cleaned up unneeded Freetype2 stuff in host.def

* Fri Jun  8 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-0.5.6
- Take-1 at cleaning up some of the font related 'issues' due to the different
  way fonts are generated in 4.1.0.  Still many issues remaining.

* Wed Jun  6 2001 Mike A. Harris <mharris@redhat.com>
- Folding the external Mesa into XFree86 created as many problems as it
  solved.  The DRI CVS trunk has a more permanent solution worth checking out.
- Since the V4L drivers have aparently been included in the main XFree86
  package all this time, I've removed the separate package.

* Mon Jun  4 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-0.1.5
- First stab at assimilating Mesa 3.4.2 package into XFree86 package
- Added missing symbols to glint driver (#42751)

* Mon Jun  4 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-0.0.2
- Rebuilt against Mesa 3.4.2 in new environment

* Sat Jun  2 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-0.0.1
- XFree86 4.1.0 released - built 4.1.0-0.0.1

* Thu May 31 2001 Mike A. Harris <mharris@redhat.com> 4.0.99.901-0.0.6
- Remove GLw manpages since we don't ship libGLw (#41791)
- I finally got XIE and PEX disabled completely for sure this time absolutely
  no question.  No really...  It's gone.

* Wed May 30 2001 Mike A. Harris <mharris@redhat.com> 4.0.99.901-0.0.4
- Updated to 4.0.99.901, removed unneeded patches
- Removed Glide3 Provides/Obsoletes from devel package, and removed the
  Glide3 devel stuff from that package also - only X needs it during build
- Removed BuildGlide3 conditional - Glide3 will always be built from now on
- Added conditionals BuildPEX & BuildXIE.  These have officially been obsoleted
  by XFree86, and are no longer actively supported or used by anything.

* Mon May 28 2001 Mike A. Harris <mharris@redhat.com> 4.0.99.900-0.2.5
- Added "Options" database file, and also the following apps and their
  manpages:  dpsexec, dpsinfo, texteroids, xftcache
- Removed hardcopy doc creation code (groff) from specfile.  The XFree86
  makefiles have been fixed now to do this themselves properly.
- Removed Glide3 headers from XFree86-devel.  Only needed during build, no
  apps should be linking to Glide3.
- Simplified filelist for libs subpackage by using globs instead of hard
  coded library version numbers.
- Removed use-cpp patch, done with imake now.

* Sun May 27 2001 Mike A. Harris <mharris@redhat.com> 4.0.99.900-0.2.2
- Merged bero's changes to my local sources, and changed libXmuu inclusion
  from libXmuu.* to libXmuu.1.0, so that the *.so doesn't get picked up also,
  as it should be in the devel package.

* Mon May 21 2001 Bernhard Rosenkraenzer <bero@redhat.com> 4.0.99.900-0.2.1
- Add missing libXmuu.* files

* Sun May 20 2001 Mike A. Harris <mharris@redhat.com>
- Many fixes from H. J. Lu <hjl@gnu.org> including enhanced parallel make,
  xterm-xaw3d, pex patches, specfile updates, build enhancements and a
  partridge in a pear tree.  ;o)
- Fixed insane off-the-screen indenting levels in xfs.init

* Sat May 19 2001 Mike A. Harris <mharris@redhat.com>
- Updated to 4.0.99.900
- Updated with the latest parallelmake patch from H. J. Lu <hjl@gnu.org>
- Added new specfile option ParallelBuild, so that any parallel build
  stuff can be conditionally defined in the specfile in case the parallel
  make patch breaks in the future.

* Fri May 11 2001 Bernhard Rosenkraenzer <bero@redhat.com>
- Fix build

* Wed May  9 2001 Mike A. Harris <mharris@redhat.com> 4.0.99.3-0
- Updated 4.0.99.x package to 4.0.99.3 release, forward ported all
  relevant changes that have occured in 4.0.3 packaging since March 27th
  until now, and brought the 4.0.3 specfile changelogs into the 4.0.99.3
  spec changelog.  The two releases should be syncronized now.

* Mon May  7 2001 Mike A. Harris <mharris@redhat.com> 4.0.3-14
- Syncronize XFree86 with Mesa 3.4.1-1
- Disable alpha-hack from May 3rd and add new patch from Compaq to replace it

* Fri May  4 2001 Mike A. Harris <mharris@redhat.com> 4.0.3-13
- Updated patch0 to latest XFree86 stable branch for 4.0.3.  Fixes many
  3dfx bugs in tdfx driver.
- Moved locale data from /usr/X11R6/lib/X11/locale in main package to
  XFree86-libs package where it belongs. (#38408)
- Corrected dumb reversal in XFree86CustomVersion Imake define in specfile
    
* Thu May  3 2001 Mike A. Harris <mharris@redhat.com> 4.0.3-12
- Reverted ia64-int10 patch from Alpha.
- Added XFree86-4.0.3-alpha-hack-bypass-int10bug.patch from
  Jay Estabrook for Alpha.

* Wed May  2 2001 Mike A. Harris <mharris@redhat.com> 4.0.3-11
- Removed RPM_BUILD_ROOT from glide section (#38031)
- Enabled XFree86-4.0.2-ia64-int10.patch on alpha as well for testing.

* Wed Apr 25 2001 Mike A. Harris <mharris@redhat.com>
- Added XFree86-4.0.3-compose-kill-ctrl-shift-t.patch to fix (#23473)

* Mon Apr 23 2001 Mike A. Harris <mharris@redhat.com>
- Added rhl-startupmessages patch to aide debugging and troubleshooting
  bug reports.  This should increase the usefulness of user submitted
  XFree86 log files and decrease the turnaround time on requesting info
  and waiting for someone to provide that info.  Patch doesn't do much yet,
  but will be enhanced later.
- Added xset manpage enhancement

* Sat Apr 21 2001 Mike A. Harris <mharris@redhat.com> 4.0.3-10
- ifarch'd XFree86-4.0.2-agpgart-load.patch to only apply on non-alpha

* Sat Apr 14 2001 Mike A. Harris <mharris@redhat.com> 4.0.3-9
- Removed dependancy of main XFree86 package on xfs by moving the XFree86
  server modules "/usr/X11R6/lib/modules/{codeconv,fonts}/*" from the xfs
  subpackage to the main XFree86 package as they never belonged in the xfs
  package in the first place.  This is an ancient packaging error.
- Added patch from Tim Waugh to fix Xaw password entry in vnc.  (#19231)

* Thu Apr 12 2001 Mike A. Harris <mharris@redhat.com>
- Killed ancient non-FHS compliant symlink to /usr/man/X11
- Disabled XFree86-4.0.3-savage-glitch.patch to fix (#34376)

* Mon Apr  9 2001 Mike A. Harris <mharris@redhat.com>
- Made glidelink get called before ldconfig in %%post libs

* Mon Apr  9 2001 Mike A. Harris <mharris@redhat.com> 4.0.3-8
- Simplified the main package %%pre script symlink munge code
- Fixed bug in %%post xfs section - inadvertently added in 4.0.3-6 release
- Disable patch #220 as it is unnecessary - taken care of via Imake ages ago.

* Sun Apr  8 2001 Mike A. Harris <mharris@redhat.com> 4.0.3-7
- Fixed (#32574) by adding a preinstall script on xdm which moves the dir
  /etc/X11/xdm/authdir to /var/lib/xdm/authdir if it exists, and symlinking
  /etc/X11/xdm/authdir to it.  Corrected the filelist for xdm to include
  these changes.
- Fixed alpha build failure with tga driver patch, ifdef with no macro.

* Fri Apr  6 2001 Mike A. Harris <mharris@redhat.com> 4.0.3-6
- Force enabled BuildXinerama and BuildXineramaLibrary in hosts.def
- FHS compliant manpage sections (4x/7x)

* Thu Apr  5 2001 Mike A. Harris <mharris@redhat.com>
- Added new patches submitted by Compaq for various drivers, etc.
  XFree86-4.0.3-compaq-alpha.patch, XFree86-4.0.3-compaq-glint.patch
  XFree86-4.0.3-compaq-radeon.patch, XFree86-4.0.3-compaq-r128.patch
  XFree86-4.0.3-compaq-mga.patch, XFree86-4.0.3-compaq-tga.patch
  (courtesy of Jay Estabrook)

* Thu Mar 29 2001 Mike A. Harris <mharris@redhat.com> 4.0.3-5
- XFree86 4.0.3 defaults to building libfreetype if Xft is being built,
  so freetype is now disabled with Imake defines.
- Removed shared libsXxf86dga and libXv hack I added on Mar 9 and
  did it properly with Imake defines.  Also fixes (#31232)

* Wed Mar 28 2001 Mike A. Harris <mharris@redhat.com> 4.0.3-4
- Added patch XFree86-4.0.3-glide3-libdir.patch so tdfx driver
  can find the Glide3 libs included with X package.
- Minor xfs.init fix
- Added XFree86-4.0.3-mga-hwcursor-fix.patch

* Tue Mar 27 2001 Mike A. Harris <mharris@redhat.com>
- Updated g450 port from 4.0.3 to XFree86-4.0.99.1-mga-g450-dualhead.patch
- Updated Savage driver dropin to version 1.15
- Added patches 405 - 408 from 4.0.3-4 build

* Sun Mar 25 2001 Mike A. Harris <mharris@redhat.com>
- Initial specfile fork of 4.0.99.1 from 4.0.3-3
- Removed unneeded patches:  XFree86-4.0.1-dri-sym.patch,
  XFree86-4.0.2-mga-busmstr.patch, XFree86-4.0.2-r128-busmstr2.patch,
  XFree86-4.0.2-r128-mobility.patch, XFree86-4.0.2-agpgart-load.patch,
  XFree86-4.0.2-r128-drm-do-wait-for-fifo.patch
- Updated patches: XFree86-4.0.99.1-parallelmake.patch,
  XFree86-4.0.99.1-locale-euro.patch, XFree86-4.0.99.1-winkey-alt-meta.patch  

* Fri Mar 23 2001 Mike A. Harris <mharris@redhat.com> 4.0.3-3
- Drumroll...... Final (or is it?) working G450 dualhead update.  ;o)

* Thu Mar 22 2001 Mike A. Harris <mharris@redhat.com>
- Added pam patch for xdm from Nalin <nalin@redhat.com> Patch404

* Wed Mar 21 2001 Mike A. Harris <mharris@redhat.com>
- Fixed uninitialized memory reference in xlib (Patch401)  (#32222)
- Make libs subpackage depend on kudzu-devel, pciutils-devel for 
  Glide3 (#32534)
- Matrox G450 updates

* Mon Mar 19 2001 Mike A. Harris <mharris@redhat.com> 4.0.3-2
- Fixed glitch in %%post xfs section of spec (#32281)
- Set "umask 133" in xfs initscript so that fonts.dir/fonts.alias files 
  created during script execution work also for non-root users that may
  have changed root's umask.
- Updated Mesa dependancy in specfile to 3.4-13

* Sun Mar 18 2001 Mike A. Harris <mharris@redhat.com>
- Removed XFree86-4.0.1-xterm-appdefaults.patch as it was redundant

* Sat Mar 17 2001 Mike A. Harris <mharris@redhat.com> 4.0.3-1
- New XFree86 4.0.3 released and integrated.
- Updated patches for 4.0.3, removed unneeded patches.
- Built 4.0.3-1

* Fri Mar 16 2001 Mike A. Harris <mharris@redhat.com>
- Reverted G450 driver back to dwmw2's driver.
- Built 4.0.2a-2

* Thu Mar 15 2001 Mike A. Harris <mharris@redhat.com> 4.0.2a-1
- Added XFree86-4.0.2-locale.patch from Phil Knirsch <pknirsch@redhat.com>
  which should fix all problems with euro locales, and other locale issues
  including bug id's (26300,21882,28447, others)
- xfs crash errors should all be fixed now by the XFree86 stable branch
  patch.  Bugzilla (#22538)

* Wed Mar 14 2001 Mike A. Harris <mharris@redhat.com> 4.0.2a-1
- New patch XFree86-4.0.2a-mga-g450-dual_6.patch - G450 driver update 
  from Luugi Marsan <lmarsan@matrox.com>
- Added new euro locale stuff from Phil Knirsch <pknirsch@redhat.com>
- Added XFree86-4.0.2-r128-drm-do-wait-for-fifo.patch from Gareth Hughes
  which should fix the r128 errors in (#26999)
  
* Tue Mar 13 2001 Mike A. Harris <mharris@redhat.com>
- Added provides entries for Glide3 in libs and devel subpackages
- Take 2 of XFree86-4.0.2a-im-being-included-and-i-cant-get-up2.patch
- Moved XftConfig file to /etc/X11 and made compatibility symlink.

* Fri Mar  9 2001 Mike A. Harris <mharris@redhat.com>
- Updated main tarball to 4.0.2a (even though it's the same code we had before
  with 4.0.2 + stable branch patch).
- Updated stable branch patch to bring 4.0.2a up to date with xf-4_0_2a-branch
- Nvidia nv driver updated with MANY fixes from XFree86 stable branch
- Added shared libraries: libXv.so, libXxf86dga.so
- Re-enabled Sparc build.  That machine is slow, someone
  needs to put a spark under it to get it going.  ;o)
- Fixed (#13882) with XFree86-4.0.2-winkey-alt-meta.patch
- Fixed (#19308) added X11R6-contrib obsolesence

* Fri Mar  9 2001 Bill Nottingham <notting@redhat.com> 4.0.2-12.1
- fix glide dependencies

* Thu Mar  8 2001 Mike A. Harris <mharris@redhat.com> 4.0.2-12
- Fixed alpha/ia64 build problems
- Built 4.0.2-12

* Tue Mar  6 2001 Mike A. Harris <mharris@redhat.com>
- Created XFree86-4.0.2-r128-mobility.patch to enable external display
  on Rage Mobility laptops, etc.
- Added XFree86-4.0.2-xft-match.patch (from Bero) (#30836)
  
* Mon Mar  5 2001 Mike A. Harris <mharris@redhat.com>
- Added XFree86-4.0.2-alpha-pci-resource.patch (#30417)

* Sat Mar  3 2001 Mike A. Harris <mharris@redhat.com>
- Glide3 is back (was previously removed on Feb 22)
- Removed loaderProcs.h hack, and replaced with a patch.
- Tidied up a tonne of XFree build warnings
- Added XFree86-4.0.2-im-being-included-and-i-cant-get-up.patch stop
  loaderProcs.h from being wrongly included in building Xnest due to
  a compiler bug.

* Fri Mar  2 2001 Mike A. Harris <mharris@redhat.com>
- Added mga and r128 busmaster patches that Todd Nix <todd@xymox.us.dell.com>
  sent me from Kevin E Martin <martin@valinux.com>.

* Wed Feb 28 2001 Mike A. Harris <mharris@redhat.com> 
- Updated xf-4_0_2-branch patch to today's latest stable code
- Removed unneeded patches after update: XFree86-4.0.2-time.patch,
  XFree86-4.0.2-sis-unresolved-memcpy.patch    
- Added XFree86-4.0.2-agpgart-load.patch from Bill Nottingham to force
  load AGPgart kernel module when a DRI module is loaded.
- Fixed "chmod" in xfs.init (#18573)
- Added BuildPreReq ncurses-devel
- Repaired ia64 int10 patch
- Tidied up specfile, particularly the host.def generation section, and 
  incorporated xfree86.def mess into host.def section where it belongs.

* Tue Feb 27 2001 Mike A. Harris <mharris@redhat.com> 4.0.2-11
- Added updated driver for Savage chipset.  Should fix all known issues
  with Savage cards that I'm aware of.
- Removed Prereq of chkfontpath on xfs subpackage and modified xfs initscript
  to only call chkfontpath if it is installed.
  
* Mon Feb 26 2001 Mike A. Harris <mharris@redhat.com> 4.0.2-10
- Added specfile %%pre fix for (#26857) - problem upgrading to
  Wolverine from Red Hat 5.2 due to directory/symlink fu glitch.
- Enabled Utempter for xterm with "UseUtempter" in specfile
- Added neomagic softcursor patch for (Helge Deller <hdeller@redhat.de>)
- Built 4.0.2-10
- Created patch XFree86-4.0.2-sis-unresolved-memcpy.patch to fix
  bugs (#19530,24670)

* Fri Feb 23 2001 Mike A. Harris <mharris@redhat.com>
- Added spec hack to fix bad include of loaderProcs.h in miinitext.c
  I believe this fixes some of the r128 DRI problems.  I can't get
  r128 DRI to crash anymore now anyways.  It isn't mind blowingly 
  fast though.  May have fixed other problems as well.  X seems much
  smoother now, and VT switching is much faster also.

* Thu Feb 22 2001 Mike A. Harris <mharris@redhat.com>
- Added ExcludeArch tag to quell failed sparc builds (unsupported)
- Re-enabled DRI for mga/r128, but they still do not work

* Sat Feb 17 2001 Mike A. Harris <mharris@redhat.com>
- Updated fix for xfs death bug with truetype fonts.
- Added chkfontpath require to xfs subpackage (#19603)
- Added XFree86-4.0.2-banshee-ramtiming.patch to fix (#26351,#18810)
- Added ia64-int10 patch. (Bill Nottingham)

* Thu Feb 15 2001 Mike A. Harris <mharris@redhat.com>
- Fixed xfs.config

* Tue Feb 13 2001 Mike A. Harris <mharris@redhat.com>
- Disabled DRI drivers r128 and mga because they are broken.
- Built XFree-4.0.2-8
- Fixed bad noarch thing
- Built XFree-4.0.2-9

* Mon Feb 12 2001 Mike A. Harris <mharris@redhat.com>
- Merged in separate XFree86-ISO8859-2 font package

* Sun Feb 11 2001 Mike A. Harris <mharris@redhat.com>
- Added 1400x1050 modeline patch for newer laptops
- Misc fixups
- Disabled DRM kernel module building as we don't use these modules
  anyway.
- Updated 4.0.2-branch patch
- Updated XFree86-4.0.2-xfree86.lst.patch

* Thu Feb 08 2001 Mike A. Harris <mharris@redhat.com>
- Internationalized xfs and xdm initscripts

* Wed Feb 07 2001 Mike A. Harris <mharris@redhat.com>
- New fix for Cirrus 5480 (H.J. Lu)
- Matrox g450 patch that _hopefully_ works this time (from dwmw2)

* Tue Feb 06 2001 Mike A. Harris <mharris@redhat.com>
- (#25890,#26131) tdfx dri driver not included.. specfile mixup, fixed.
- (#23896) Added option for building with Glide2 (default=off).  Dunno if
  it works or not as I'm not testing it.  If someone wants to further the
  enhancement at all, I'll accept specfile patches to add any missing bits. ;o)
- (#25131) Fixed xfs.config file glitch (Truetypex typos), and a similar
  bug in specfile hack.
- Updated to recent XFree86 stable bug fixes (Patch #1)
- Fix temp files vulnerabilites in xman on systems with mkstemp()
- Fix temp vulnerabilities in Xaw/MultiSrc.c
- Fix temp file vulnerability in gccmakedep based on report from Alan Cox.
- Fix temp file vulnerability in Imake.rules
- Fix temp file vulnerability in InstallManPageAliases
- Fix Neomagic 2200 screen corruption
- Add an imake control for determining when xload should be installed set-gid

* Thu Jan 25 2001 Mike A. Harris <mharris@redhat.com>
- Added g450 patch from Matrox.  Lets see some dualhead action baby!
- Filtered out M$ Windows CR's from the Matrox patch, hope I got them
  all.  Windows bad, Linux good.  ;o)
- Removed all prior g450 patches as the new one repaces them all
- Many spec file simplifications, and general tidy up job.

* Wed Jan 24 2001 Bill Nottingham <notting@redhat.com>
- fix perms on xload

* Wed Jan 24 2001 Matt Wilson <msw@redhat.com>
- chmod 644 XftConfig before piping to it

* Wed Jan 24 2001 Mike A. Harris <mharris@redhat.com>
- Disable Cirrus 5480 patch as it wont apply cleanly to 4.0.2.
- Removed v4l patch - its in 4.0.2 already
- (#23701) devel dependant on libs instead of main package.
- Added TrueType font dirs to config files for the ttfonts package
- Numerous other tweaks
- XFree86-4.0.2-4 built

* Tue Jan 23 2001 Mike A. Harris <mharris@redhat.com>
- Fixed xfs initscript to only start at boot time if X is installed.
- Put eurofonts package back and fixed it up with suggestions from
  H. J. Lu - as 2 font files are still needed.
- Changed xload %%install time chmod to %%attr instead
- Tidied up %%install section, removing redundancies.
- Added Cirrus Logic 5480 patch from from Egbert Eich (#24177)

* Mon Jan 22 2001 Mike A. Harris <mharris@redhat.com>
- Removed manpage "hack" section from specfile
- Removed eurofont tarball entirely.  It's included in X already under
  different names now.
- Removed mga, ATI, mesa patches from yesterday as they fail the
  build requiring many other missing items.
  
* Sun Jan 21 2001 Mike A. Harris <mharris@redhat.com>
- Added ATI driver patch from XFree CVS - lots of new fixes
- Added mga driver patch from XFree CVS (mainly for G450)
- Added mesa patch from XFree CVS
- Added BuildPrereq: pam-devel  (Bill Crawford <billc@netcomuk.co.uk>)
- Commented out BuildPrereq: pam-devel as it failed me
- Remove eurofont .bdf files after pcf's are created to quell duplicate
  font errors.

* Sat Jan 20 2001 Mike A. Harris <mharris@redhat.com>
- Added Xft update from XFree CVS
- Updated %%clean section
- Changed specfile bunzip references to bzcat
- Fixed all specfile references of "tar x" to "tar xf -"
- Added romanian-keyboard-fix from Cristian Gafton <gafton@redhat.com>

* Thu Jan 18 2001 Mike A. Harris <mharris@redhat.com>
- ATI r128 update from ATI.

* Wed Jan 17 2001 Mike A. Harris <mharris@redhat.com>
- Disabled tdfx builds as they die with missing glide3 libs
  (at least in RHL 7.0 it does)

* Tue Jan 16 2001 Mike A. Harris <mharris@redhat.com>
- Added BuildPrereq: flex >= 2.5.4a
- Added BuildPrereq: freetype-devel >= 2.0.1
- Added BuildPrereq: Glide3-devel >= 20001220 for tdfx

* Mon Jan 15 2001 Mike A. Harris <mharris@redhat.com>
- Updated fhs patch for 4.0.2
- Updated portuguese patch for 4.0.2

* Thu Jan 11 2001 Mike A. Harris <mharris@redhat.com>
- Integrated Matrox G450 driver for testing from Matrox

* Mon Jan 8 2001 Mike A. Harris <mharris@redhat.com>
- Added xfree86.lst patches from Brent Fox and also (#5977)
 
* Sat Jan 6 2001 Mike A. Harris <mharris@redhat.com>
- Misc spec file fixups

* Fri Jan 5 2001 Mike A. Harris <mharris@redhat.com>
- Integrated ATI driver from Michael Smith <msmith@ati.com>

* Wed Jan 3 2001 Mike A. Harris <mharris@redhat.com>
- Built 4.0.2 release 1

* Thu Dec 28 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- Add a couple of missing man pages, noted by Thayne Harbaugh <thayne@plug.org>
- Use system freetype, now that we've updated
- Add missing XftConfig file

* Thu Dec 28 2000 Bill Nottingham <notting@redhat.com>
- don't list the driver modules explicitly; ship them all

* Thu Dec 21 2000 Bill Nottingham <notting@redhat.com>
- integrate tdfx_dri into main XFree86 package

* Tue Dec 19 2000 Bill Nottingham <notting@redhat.com>
- fix typos in xkb symlink/dir munging

* Tue Dec 19 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- Add missing Xft (Xrender) includes in -devel
- Move xkb files back to their old locations, we can't replace directories
  with symlinks
- Add /etc/X11/xkb -> /usr/X11R6/lib/X11/xkb symlink for compatibility
- 4.0.2
- Get rid of twfix patch (it's in 4.0.2)
- Patch 302 must be applied with -p0, not -p1
- Add a %%clean section
- Get rid of /etc/X11/xdm/xdm-config in XFree86-xdm. Since kdm uses it, as well,
  it should be in xinitrc

* Thu Dec 14 2000 Mike A. Harris <mharris@redhat.com>
- Added XFree86-4.0.1-twfix.patch from bhuang@redhat.com to fix
  zh_TW locale.
- Added locale.alias patch from Jakub Jelinek.
- Removed unneeded patches, and tidied spec file a bit (yeah right). ;o)

* Wed Dec 13 2000 Bill Nottingham <notting@redhat.com>
- tweak the -pic patch so it works with the ELF loader (in theory)
- don't try and build the kernel modules

* Sun Dec 10 2000 Bill Nottingham <notting@redhat.com>
- reapply the parallelmake patch
- hm, libX11 and libXmu are now .6.2

* Sat Dec 9 2000 Mike A. Harris <mharris@redhat.com>
- Updated to CVS version xf-4.0.1Z

* Sat Dec  9 2000 Bill Nottingham <notting@redhat.com>
- add back in some patches (FHS, Xwrapper)
- make it build on ia64 (hopefully)

* Fri Dec 8 2000 Mike A. Harris <mharris@redhat.com>
- Added patch XFree86-4.0.1h-xf86Wacom.c-kernelheaderclash.patch to
  fix 4.0.1h build failure.

* Wed Dec 6 2000 Mike A. Harris <mharris@redhat.com>
- Fixed bug (#21303) changed 2 uses of arch "i386" to "%{ix86}"
- Remove dependancy on tar 1.13.18 by calling bunzip2 and piping to tar
- Removed I810Drm.tar.gz entirely as it smashes other dri code (mga,etc)
  and is ancient

* Wed Dec 6 2000 Mike A. Harris <mharris@redhat.com>
- Updated to CVS version xf-4.0.1h which includes many updates and
  integrates many Red Hat patches directly into XFree86 CVS.

* Sat Nov 10 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- Update to current. This should fix, among other things, DRI/DRM stuff on
  Matrox cards and i18n.
- Fix build with tar 1.13.18
- Add XKB patch for Romanian keyboards from Christian Gafton <gafton@redhat.com>
- Fix up Euro sign support

* Wed Oct 25 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- Don't apply the PIC patch on non-ia64 platforms, it breaks X startup on x86.

* Mon Sep 25 2000 Bill Nottingham <notting@redhat.com>
- minor tweaks for ia64/glibc-2.2 build

* Thu Aug 24 2000 Bill Nottingham <notting@redhat.com>
- never mind, it doesn't. Wheee.

* Wed Aug 23 2000 Bill Nottingham <notting@redhat.com>
- oops, the r128 mobility patch breaks regular r128 cards

* Tue Aug 22 2000 Bill Nottingham <notting@redhat.com>
- fix DGA for real
- add support for the r128 Mobility chips

* Tue Aug 15 2000 Bill Nottingham <notting@redhat.com>
- fix xterm app-defaults file (#13584)
- don't build a shared xdm greeter lib

* Mon Aug 14 2000 Bill Nottingham <notting@redhat.com>
- fixes for MGA dri (text corruption)
- spell Portuguese correctly in keymap list (#12343)
- fix some absolute symlinks (#16133)
- fix xman's man config path (#15974)
- fix broken xdm pam code (#15952)
- fix bug in ATI driver (#14344)

* Fri Aug 11 2000 Bill Nottingham <notting@redhat.com>
- revert some of the i810 code; it breaks VC switching

* Sun Aug  6 2000 Bill Nottingham <notting@redhat.com>
- fix DGA so that 4.x-compiled DGA1 apps can run against 3.3.x servers
- fix tempfile handling in makedepend
- use cpp, not gcc -E 

* Fri Aug  4 2000 Bill Nottingham <notting@redhat.com>
- more CVS updates (Neomagic fixes, some i810)
- fix sparc build

* Thu Aug  3 2000 Bill Nottingham <notting@redhat.com>
- do *not* do xfs stop/start in condrestat

* Wed Aug  2 2000 Bill Nottingham <notting@redhat.com>
- update CVS (i810 fixes, others)
- move some more files out of -xdm, into xinitrc package
- remove /usr/share/fonts/default/TrueType from default xfs config (#14683)
- fix weirdness in the i810 driver update

* Wed Aug  2 2000 Matt Wilson <msw@redhat.com>
- hack to work around gcc bug triggered by xwd (patch207)
- modified xfs post script to add in no-listen = tcp per Bill's request

* Tue Jul 25 2000 Elliot Lee <sopwith@redhat.com>
- Some i810/i815 stuff (new I810Drm.tar.gz, updated to xf4.0.1-I810copy.patch only to find out
that it is already included in this source tree).

* Mon Jul 24 2000 Bill Nottingham <notting@redhat.com>
- add patch for xf86 vidmode extension
- add icelandic keymap to list of keymaps

* Sat Jul 22 2000 Bill Nottingham <notting@redhat.com>
- hey, we recognize the geforce2 now. Wonder if it works. :)

* Thu Jul 19 2000 Bill Nottingham <notting@redhat.com>
- oops, I broke the sparc Mach64 patch on sparc

* Wed Jul 18 2000 Bill Nottingham <notting@redhat.com>
- move initscript back
- update CVS
- remove Mesa (use its own separate package for easier updating)
- kill the GL wrapper
- fix linking of dri modules so that symbol resolution with Mesa works right
- add sparc Mach64 patch from DaveM
- fix sparc Mach64 patch so it builds
- add ffb patch from Jakub
- fix xfs user creation

* Fri Jul 14 2000 Elliot Lee <sopwith@redhat.com>
- Fix Mesa library version info
- Set Mesa package version to reflect Mesa version (not the XFree86
  version), and set release to something that will facilitate upgrades
  from older Mesa pkgs while still being informative.
- Only pass -j to toplevel make, which takes care of passing it on down.

* Thu Jul 13 2000 Preston Brown <pbrown@redhat.com>
- fixed xfs condrestart to do a real stop/start.
- fonts.* files in font directories are config(noreplace)

* Thu Jul 13 2000 Elliot Lee <sopwith@redhat.com>
- Update Mesa to 3.2 release.
- Use mmx/sse/x86 stuff for Mesa on 386 and up, not just if building for 686 (since MMX is
available on 586 many times, and since the functionality is runtime-configured).
- Try to integrate newer i810/i815 driver (unfinished)

* Mon Jul 10 2000 Bill Nottingham <notting@redhat.com>
- update CVS while I'm here
- don't use ix86 PCI code on ia64
- fix some int/long bogosity in some of the drivers

* Sat Jul  8 2000 Bill Nottingham <notting@redhat.com>
- update CVS
- build with new compiler to fix Xserver problems on i386
- add parallel make patch from H. J. Lu

* Tue Jul  4 2000 Bill Nottingham <notting@redhat.com>
- oops, open the right software Mesa lib
- build DRI everywhere

* Mon Jul  3 2000 Bill Nottingham <notting@redhat.com>
- fix Mesa install
- add Romanian keymap so keymaps get installed

* Sun Jul  2 2000 Bill Nottingham <notting@redhat.com>
- add console.apps file for xserver (#13325)
- prereq chkfontpath for font packages
- update CVS
- bump version to 4.0.1
- add lemming patch

* Fri Jun 30 2000 Bill Nottingham <notting@redhat.com>
- update CVS, sparc patches now included
- ship pam files
- point X symlink to Xwrapper, not XFree86

* Thu Jun 29 2000 Bill Nottingham <notting@redhat.com>
- fix pamsession, xfsredhat patches
- turn off joystick, it relies on magic symbols defined *nowhere*

* Wed Jun 28 2000 Preston Brown <pbrown@redhat.com>
- merged in a bunch of patches from 3.3.6 that somehow got dropped including:
- xkb changes
- some xfs changes
- xterm app-defaults
- pam session fix for xdm
- define some paths in host.def instead of a wild mess of patches
- kill compat links from /etc/X11/<dirname> to /usr/X11R6/lib/X11/<dirname>

* Wed Jun 28 2000 Bill Nottingham <notting@redhat.com>
- add Mesa wrapper
- put Mesa libs in /usr/lib
- return of Xwrapper
- take setuid off XFree86

* Wed Jun 28 2000 Jakub Jelinek <jakub@redhat.com>
- remove 3 obsolete SPARC patches
- add 2 new ones

* Tue Jun 27 2000 Bill Nottingham <notting@redhat.com>
- put setuid on XFree86 (temporary)
- yank setuid off xload 
- put the xfs %%pre back in
- xfs initscript munging
- fix ia64 patches

* Tue Jun 27 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- Update to current CVS

* Thu Jun 22 2000 Bill Nottingham <notting@redhat.com>
- return of the font %%post/%%postuns
- move some of the xdm stuff to xinitrc
- put libglut in with Mesa

* Sun Jun 18 2000 Matt Wilson <msw@redhat.com>
- build glint module on alpha

* Thu Jun 15 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- Fix up Xaw (Bugs #11404 and #11426)
- more FHS fixes (fix bug #11358 and some related unreported bugs)

* Wed Jun 14 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- split off Mesa and Mesa-devel
- FHSify
- fix build on alpha and ia64

* Wed Jun  7 2000 Bill Nottingham <notting@redhat.com>
- merge in ia64 fixes

* Fri Jun  2 2000 Nalin Dahyabhai <nalin@redhat.com>
- change PAM configuration to use system-auth
- build fix for Sparc

* Tue May 23 2000 Jakub Jelinek <jakub@redhat.com>
- don't define GlxStubLib if DllModules is not defined -
  otherwise things don't compile on i386

* Mon May 22 2000 Jakub Jelinek <jakub@redhat.com>
- support ffb, leo and cg6 on sparc
- only switch to dlopen() loader on selected architectures

* Thu May 11 2000 Bill Nottingham <notting@redhat.com>
- switch to dlopen() loader

* Wed May 10 2000 Bill Nottingham <notting@redhat.com>
- add man pages to -devel

* Sun May  7 2000 Bill Nottingham <notting@redhat.com>
- more directory shuffles

* Fri May  5 2000 Bill Nottingham <notting@redhat.com>
- more random fixes

* Wed May  3 2000 Bill Nottingham <notting@redhat.com>
- various fixes
- fix specfile for ia64
- merge drivers back into XFree86 package

* Sun Apr 23 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- update xf86cfg
- fix up the xf86cfg patch
- various fixes

* Thu Apr 20 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- Fix up x11perfcomp and move it to -tools
- Fix up xfs (missing init script...)
- chkconfig'ize xfs
- move pswrap to -devel

* Sat Apr  8 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- Add xf86cfg (successor to XF86Setup, taken from the XFree86 4.0a tree
  with permission from the patch author)
- Move the directory fixup stuff from %pre to %triggerpostun -- XFree86 < 3.9
  We don't want to fix things twice...

* Wed Apr  5 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- Fix post script breakage
- Disable build root strip policy (drivers can't be stripped)
- strip the stuff we can safely strip manually
- add /usr/include stuff
- add some stuff from Mesa - we don't really want to obsolete Mesa
  without providing GLU and glut.
- move some man pages from XFree86 to XFree86-tools, where they belong.
- move some files to subpackages:
  beforelight, xclipboard, xclock, xfd, xieperf, xmag, xwininfo are now
  in XFree86-tools (rather than XFree86)
  makeg is now in XFree86-devel (rather than XFree86)
- obsolete Mesa, glxMesa* and xpm in -libs
- hope it still compiles

* Tue Apr  4 2000 Jakub Jelinek <jakub@redhat.com>
- Even move sparc tweaks

* Sat Apr  1 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- Make it compile on sparc (Patch from Jakub Jelinek <jakub@redhat.com>,
  some additional fixes from me)
- Autodetect the right version of Tcl/Tk
- remove xinitrc, we get it from the xinitrc package

* Sat Mar 18 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- More fixes
- Fix compilation on alpha
- TODO: Port our 3.3.6 patches

* Wed Mar 15 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- Add the man pages ;)
- Merge some patches from the RPMs at seawood.org
- Various fixes

* Mon Mar 13 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- Initial RPM

